# -*- coding: utf-8 -*-
#
# External Code Sets (created 2019-06-15)
# https://www.iso20022.org/external_code_list.page
#
# This file is part of the Python FinTech Package
# http://www.joonis.de/fintech
#
# Copyright (c) 2019 joonis new media
# Author: Thimo Kraemer <thimo.kraemer@joonis.de>

from __future__ import division, absolute_import, print_function, unicode_literals


# ExternalAccountIdentification1Code
ACCOUNT_IDENTIFICATION = {
    'AIIN': 'IssuerIdentificationNumber: Issuer Identification Number (IIN) - identifies a card issuing institution in an international interchange environment. Issued by ABA (American Bankers Association).',
    'BBAN': 'BBANIdentifier: Basic Bank Account Number (BBAN) - identifier used nationally by financial institutions, ie, in individual countries, generally as part of a National Account Numbering Scheme(s), to uniquely identify the account of a customer.',
    'CUID': 'CHIPSUniversalIdentifier: (United States) Clearing House Interbank Payments System (CHIPS) Universal Identification (UID) - identifies entities that own accounts at CHIPS participating financial institutions, through which CHIPS payments are effected. The CHIPS UID is assigned by the New York Clearing House.',
    'UPIC': 'UPICIdentifier: Universal Payment Identification Code (UPIC) - identifier used by the New York Clearing House to mask confidential data, such as bank accounts and bank routing numbers. UPIC numbers remain with business customers, regardless of banking relationship changes.',
}

# ExternalBalanceSubType1Code
BALANCE_SUB_TYPE = {
    'ADJT': 'Adjustment: Balance to be held in the settlement account in order to comply with the average reserve due, in the event that the bank\'s balance is equal to the reserve due during the remaining days of the maintenance period.',
    'BCUR': 'BaseCurrency: Balance representing the amount in the domestic or base accounting currency.',
    'BLCK': 'Blocked: Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, eg, the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes. In some countries, a blocked balance is known as a \'reserve\' balance.',
    'BLKD': 'Blocked Funds: Balance representing funds that cannot be touched by the account owner.',
    'DLOD': 'DaylightOverdraft: Balance representing the intra day overdraft granted by the Central Bank to financial institutions participating in a RTGS system. This balance may vary over time and shall be offset at the end of the day.',
    'EAST': 'EligibleAssets: Balance representing the potential loan a Central Bank would make in cash if the collateral is pledged, eg, securities available and eligible as collateral with the Central Bank.',
    'FCOL': 'Firm collateralization: Balance representing the forecast of the cash-equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral.',
    'FCOU': 'Amounts that have been used to serve as firm collateral: Balance representing the cash equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral and have been used as collateral.',
    'FORC': 'SecuritiesForecast: Balance representing the total of all balance types representing the forecast of transactions to settle, blocked items, custody transactions and corporate actions cash disbursements.',
    'FUND': 'NetFunding: Balance representing the net amount to be funded resulting from the difference between the total of all transactions with a cash impact and the existing cash coverage.',
    'INTM': 'Intermediate: Balance representing an intermediate amount such as the opening or closing balance incrementally carried forward from one page to the next in a multi-page statement or report.',
    'LCUR': 'LocalCurrency: Balance representing the amount in the local market currency for which the asset is held.',
    'LRLD': 'LimitRelated: Balance of a specific limit value, eg, a bilateral balance is calculated in relation to a given bilateral limit.',
    'NOTE': 'Reserved liquidity: Balance representing the amount that a financial institution has set aside for a specific reason and which is therefore not available. In the context of CSDs, reservation of liquidity made to meet settlement obligations.',
    'PDNG': 'SecuritiesPending: Balance of securities pending delivery, such as orders to sell securities have been executed but settlement of the open transactions has not been confirmed.',
    'PIPO': 'PayInPayOut: Balance representing the fictive amount of automated direct debits or payment based on standing arrangements between the CSD and the user. Usage: Pay-Ins and Pay-Outs can be different based on individual payment instructions or available funds.',
    'PRAV': 'ProgressiveAverage: Average of the daily balances on the account used to fulfil the reserve requirements calculated from the beginning of the maintenance period.',
    'RESV': 'Reserve: Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, eg, the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes.',
    'SCOL': 'Self-collateralization: Balance representing the forecast of the cash-equivalent resulting from evaluation of the net incoming balance of securities qualified to serve as collateral for which settlement instructions are held at.',
    'SCOU': 'Amounts that have been used to serve as self collateral: Balance representing the cash-equivalent resulting from evaluation of incoming securities, qualified to serve as collateral and actually used as collateral, which have been settled during the settlement process.',
    'THRE': 'Threshold: Balance representing the amount that will be destined for investment. Difference between available balance and threshold for investment limit.',
}

# ExternalCashClearingSystem1Code
CASH_CLEARING_SYSTEM = {
    'ABE': 'EBAEuro1Step1: EBA Euro1/Step1.',
    'ACH': 'ACH: Automated Clearing House. Payment system that clears cash transfers and settles the proceeds in a lump sum, usually on a multilateral netting basis.',
    'ACS': 'Canada: Canadian Dollar (CAD)  - Automated Clearing Settlement System (ACSS)',
    'AIP': 'Albania: AL (Albania) -  Albania Interbank Payment System.',
    'ART': 'Austrian: AT (Austria) - Austrian RTGS.',
    'AVP': 'NewZealand: NZ (New Zealand) - New Zealand Assured Value Payments.',
    'AZM': 'Azerbaijan: AZ (Azerbaijan) - Azerbaijan Interbank Payment System (AZIPS).',
    'BAP': 'BosniaHerzegovina: BA (Bosnia and Herzegovina).',
    'BCC': 'SwedenBGC: SE (Sweden) - Sweden BGC Clearing CUG.',
    'BCE': 'Ecuador: EC (Ecuador) - Ecuadorian Central Payment System (Sistema Central de Pagos Ecuatoriano)',
    'BDS': 'Barbados: BB (Barbados) - Barbados RTGS (CBRTGS).',
    'BEL': 'Belgium: BE (Belgium) - Belgium RTGS (ELLIPS).',
    'BGN': 'Bulgaria: BG (Bulgaria) - Bulgaria RTGS.',
    'BHS': 'Bahamas: BS (Bahamas) - Bahamas RTGS.',
    'BIS': 'Botswana: BW (Botswana) - Botswana Interbank Settlement System.',
    'BOF': 'Finland: FI (Finland) - RTGS (BOF).',
    'BOJ': 'BankOfJapanNet: the Bank of Japan clearing system.',
    'BRL': 'Italy: IT (Italy) - Italy RTGS (BIREL).',
    'BSP': 'Philippines: PH (Philippines) - Philippines Payment System.',
    'CAD': 'Canada: CA (Canada) - Canadian Large Value Transfer System (LVTS)',
    'CAM': 'SpainCAM: ES (Spain).',
    'CBA': 'Central Bank of Aruba CSM: AW (Aruba) - Central Bank of Aruba CSM',
    'CBJ': 'Ireland: IE (Ireland) - Irish RTGS (IRIS).',
    'CHI': 'USTCHChips: US - The Clearing House CHIPS',
    'CHP': 'UnitedKingdom: GB (UK) - British Euro RTGS (CHAPS).',
    'CIS': 'Central Interoperability Service: Central Interoperability Service of the EACHA Clearing Cooperative, for exchanging SEPA payments between Automated Clearing Houses in the EEA.',
    'COE': 'Columbia: CO (Columbia) - Colombian Electronic Cheque System named CEDEC (Compensación Electrónica De Cheques).',
    'COI': 'Columbia: CO (Columbia) - Colombian Central Bank´s ACH named CENIT (Compensación Electrónica Nacional Interbancaria).',
    'COU': 'Columbia: CO (Columbia) - Colombian RTGS System named CUD (Cuentas de Depósito).',
    'DDK': 'DenmarkDDK: DK (Denmark) - Danish Krone RTGS (KRONOS)',
    'DKC': 'Denmark: DK (Denmark) - Danish Euro RTGS (KRONOS)',
    'EBA': 'EBAEuro1: EBA Euro1.',
    'ELS': 'GermanyELS: DE (Germany).',
    'EMZ': 'Germany: Elektronischer Massenzahlungsverkehr (EMZ)',
    'EPM': 'ECB: ECB (European Central Bank) - ECB Payment Mechanism.',
    'EPN': 'USTCHEPN: US - The Clearing House EPN',
    'ERP': 'EBAStep1: EBA step 1 (members).',
    'FDA': 'USFedACH: US (United States) - FED-ACH',
    'FDN': 'FedNet: FedNet is a link to a Federal Bank account via the internet.  FedNet enables checking of account balance, transactions, take print outs of account statement, transfer funds to third party accounts, E-shopping, BSNL Payments, Deposit opening, Deposit Renewal, Request for Demand Draft, Cheque Book etc.',
    'FDW': 'USFedwire: US (United States) – FEDWIRE',
    'FEY': 'ForeignExchangeYenClearing: JP (Japan) the Foreign Exchange Yen Clearing system (FEYCS). It is the Japanese electronic interbank system for sending guaranteed and unconditional yen payments of FX deals for same day settlement from one settlement bank, on behalf of itself or its customers, to another settlement bank.',
    'GIS': 'Ghana: GH (Ghana) - Ghana Interbank Settlement System (GISS).',
    'HRK': 'Croatia: HR (Croatia) - HSVP.',
    'HRM': 'Greece: GR (Greece) - Greek RTGS (HERMES).',
    'HUF': 'Hungary: HU (Hungary) - VIBER.',
    'INC': 'DEandNLEquens: DE and NL - Equens',
    'JOD': 'Jordan: JO (Jordan) - Jordan RTGS.',
    'KPS': 'Kenya: KE (Kenya) - Kenyan Electronic Payment Settlement System.',
    'LGS': 'Luxemburg: LU (Luxemburg) - Luxembourg RTGS (LIPS).',
    'LKB': 'SriLanka: LK (Sri Lanka) - Sri Lanka (Lankasettle).',
    'LVL': 'Latvia: LV (Latvia).',
    'LVT': 'Canada: CA (Canada) - Large Value Transfer System (LVTS).  Replaces CAD.',
    'MEP': 'Singapore: SG (Singapore) - Singapore RTGS (MEPS+).',
    'MOS': 'SouthAfrica: ZA (South Africa) - South-African Multiple Option Settlement.',
    'MRS': 'Malta: MT (Malta) - Malta Realtime Interbank Settlement System.',
    'MUP': 'Mauritius: MU (Mauritius).',
    'NAM': 'Namibia: NA (Namibian) - Namibian Interbank Settlement System.',
    'NOC': 'Norway: NO (Norway).',
    'NPP': 'Australia: AU (Australia) - New Payments Platform (NPP)',
    'PCH': 'Switzerland: CH (Switzerland).',
    'PDS': 'Australia: AU (Australia).',
    'PEG': 'Egypt: EG (Egypt).',
    'PNS': 'FrancePNS: FR (France).',
    'PTR': 'Angola: AO (Angola) - Angola RTGS.',
    'PVE': 'Venezuela: Ve (Venezuela).',
    'ROL': 'RomaniaEPO: RO (Romania) - Romanian Electronic Payment Operations RT.',
    'ROS': 'RomaniaGSRS: RO (Romania) - Romanian GSRS.',
    'RTG': 'RTGS: Real Time Gross Settlement System. Payment system that simultaneously clears individual transfers and settles them in central bank money.',
    'RTP': 'GermanyRTGSPlus: DE (Germany).',
    'SCL': 'RPS SEPA-Clearer: DE – SEPA-Clearer of the Retail Payment System operated by Deutsche Bundesbank',
    'SCP': 'Chili: CL (Chile) - Chilean Interbank Payment System.',
    'SEC': 'SwedenSEC: SE (Sweden) - Swedish Euro RTGS (SEC).',
    'SIT': 'Slovania: SI (Slovenia).',
    'SLB': 'SpainES: ES (Spain) - Spanish RTGS (SLBE).',
    'SPG': 'Portugal: PT (Portugal) - Portuguese RTGS (SPGT).',
    'SSK': 'SwedenSSK: SE (Sweden) - SEK RTGS (RIX).',
    'ST2': 'EBAStep2: EBA Clearing STEP 2',
    'STG': 'UnitedKingdomGBP: UK (United Kingdom) - CHAPS Sterling RTGS.',
    'TBF': 'FranceFR: FR (France) - French RTGS (TBF).',
    'TCH': 'USTCHRealTime: US - The Clearing House Real-TimePayment System',
    'TGT': 'Target: Target.',
    'THB': 'Thailand: TH (Thailand) - Thailand Payment System (BAHTNET).',
    'THN': 'Thailand-NITMX: TH (Thailand) - National ITMX Payment System',
    'TIS': 'Tanzania: TZ (Tanzania) - Tanzania Interbank Settlement System (TISS).',
    'TOP': 'Netherlands: NL (Netherlands) - Dutch RTGS (TOP)',
    'TTD': 'TrinidadAndTobago: TT (Trinidad and Tobago ) - Trinidad and Tobago SAFE-TT.',
    'UBE': 'Canada: United States Dollar  (USD) – US Bulk Exchange Clearing System (USBE)',
    'UIS': 'Uganda: UG (Uganda) - Uganda National Interbank Settlement System.',
    'VCS': 'VocaLink: VocaLink Clearing System',
    'XCT': 'EBAStep2: EBA step 2.',
    'ZEN': 'Zengin: JP (Japan) the Zengin system. The electronic payment system for domestic third party transfers managed by the Tokyo Bankers Association.',
    'ZET': 'Zimbabwe: ZW (Zimbabwe) - Zimbabwe Electronic Transfer & Settlement System.',
    'ZIS': 'Zambia: ZM (Zambia) - Zambian Interbank Payment &Settlement System.',
}

# ExternalCategoryPurpose1Code
CATEGORY_PURPOSE = {
    'BONU': 'BonusPayment: Transaction is the payment of a bonus.',
    'CASH': 'CashManagementTransfer: Transaction is a general cash management instruction.',
    'CBLK': 'Card Bulk Clearing: A Service that is settling money for a bulk of card transactions, while referring to a specific transaction file or other information like terminal ID, card acceptor ID or other transaction details.',
    'CCRD': 'Credit Card Payment: Transaction is related to a payment of credit card.',
    'CORT': 'TradeSettlementPayment: Transaction is related to settlement of a trade, eg a foreign exchange deal or a securities transaction.',
    'DCRD': 'Debit Card Payment: Transaction is related to a payment of debit card.',
    'DIVI': 'Dividend: Transaction is the payment of dividends.',
    'DVPM': 'DeliverAgainstPayment: Code used to pre-advise the account servicer of a forthcoming deliver against payment instruction.',
    'EPAY': 'Epayment: Transaction is related to ePayment.',
    'FCOL': 'Fee Collection: A Service that is settling card transaction related fees between two parties.',
    'GOVT': 'GovernmentPayment: Transaction is a payment to or from a government department.',
    'HEDG': 'Hedging: Transaction is related to the payment of a hedging operation.',
    'ICCP': 'Irrevocable Credit Card Payment: Transaction is reimbursement of credit card payment.',
    'IDCP': 'Irrevocable Debit Card Payment: Transaction is reimbursement of debit card payment.',
    'INTC': 'IntraCompanyPayment: Transaction is an intra-company payment, ie, a payment between two companies belonging to the same group.',
    'INTE': 'Interest: Transaction is the payment of interest.',
    'LOAN': 'Loan: Transaction is related to the transfer of a loan to a borrower.',
    'MP2B': 'Commercial: Mobile P2B Payment',
    'MP2P': 'Consumer: Mobile P2P Payment',
    'OTHR': 'OtherPayment: Other payment purpose.',
    'PENS': 'PensionPayment: Transaction is the payment of pension.',
    'RPRE': 'Represented: Collection used to re-present previously reversed or returned direct debit transactions.',
    'RRCT': 'ReimbursementReceivedCreditTransfer: Transaction is related to a reimbursement for commercial reasons of a correctly received credit transfer.',
    'RVPM': 'ReceiveAgainstPayment: Code used to pre-advise the account servicer of a forthcoming receive against payment instruction.',
    'SALA': 'SalaryPayment: Transaction is the payment of salaries.',
    'SECU': 'Securities: Transaction is the payment of securities.',
    'SSBE': 'SocialSecurityBenefit: Transaction is a social security benefit, ie payment made by a government to support individuals.',
    'SUPP': 'SupplierPayment: Transaction is related to a payment to a supplier.',
    'TAXS': 'TaxPayment: Transaction is the payment of taxes.',
    'TRAD': 'Trade: Transaction is related to the payment of a trade finance transaction.',
    'TREA': 'TreasuryPayment: Transaction is related to treasury operations.  E.g. financial contract settlement.',
    'VATX': 'ValueAddedTaxPayment: Transaction is the payment of value added tax.',
    'WHLD': 'WithHolding: Transaction is the payment of withholding tax.',
}

# ExternalClearingSystemIdentification1Code
CLEARING_SYSTEM_IDENTIFICATION = {
    'ATBLZ': 'Austrian Bankleitzahl: Bank Branch code used in Austria',
    'AUBSB': 'Australian Bank State Branch Code (BSB): Bank Branch code used in Australia',
    'CACPA': 'Canadian Payments Association Payment Routing Number: Bank Branch code used in Canada',
    'CHBCC': 'Swiss Financial Institution Identification (short): Financial Institution Identification (IID) used in Switzerland, without check digit',
    'CHSIC': 'Swiss Financial Institution Identification (long): Financial Institution Identification (IID) used in Switzerland, including check digit',
    'CNAPS': 'CNAPS Identifier: Bank Branch code used in China',
    'DEBLZ': 'German Bankleitzahl: Bank Branch code used in Germany',
    'ESNCC': 'Spanish Domestic Interbanking Code: Bank Branch code used in Spain',
    'GBDSC': 'UK Domestic Sort Code: Bank Branch code used in the UK',
    'GRBIC': 'Helenic Bank Identification Code: Bank Branch code used in Greece',
    'HKNCC': 'Hong Kong Bank Code: Bank Branch code used in Hong Kong',
    'IENCC': 'Irish National Clearing Code: Bank Branch code used in Ireland',
    'INFSC': 'Indian Financial System Code: Bank Branch code used in India',
    'ITNCC': 'Italian Domestic Identification Code: Bank Branch code used in Italy',
    'JPZGN': 'Japan Zengin Clearing Code: Bank Branch code used in Japan',
    'NZNCC': 'New Zealand National Clearing Code: Bank Branch code used in New Zealand',
    'PLKNR': 'Polish National Clearing Code: Bank Branch code used in Poland',
    'PTNCC': 'Portuguese National Clearing Code: Bank Branch code used in Portugal',
    'RUCBC': 'Russian Central Bank Identification Code: Bank Branch code used in Russia',
    'SESBA': 'Sweden Bankgiro Clearing Code: Bank Branch code used in Sweden',
    'SGIBG': 'IBG Sort Code: Bank Branch code used in Singapore',
    'THCBC': 'Thai Central Bank Identification Code: Bank Identification code used in Thailand',
    'TWNCC': 'Financial Institution Code: Bank Branch code used in Taiwan',
    'USABA': 'United States Routing Number (Fedwire, NACHA): Routing Transit number assigned by the ABA for US financial institutons',
    'USPID': 'CHIPS Participant Identifier: Bank identifier used by CHIPs in the US',
    'ZANCC': 'South African National Clearing Code: Bank Branch code used in South Africa',
}

# ExternalFinancialInstitutionIdentification1Code
FINANCIAL_INSTITUTION_IDENTIFICATION = {
}

# ExternalLocalInstrument1Code
LOCAL_INSTRUMENT = {
    'DDMC': 'DirectDebitConfirmedElectronicMandate: Transaction is related to a direct debit instruction authorized under a confirmed electronic mandate.',
    'DDMP': 'DirectDebitPaperMandateWithPaperAuthorization: Transaction is related to a direct debit instruction authorized under a paper based mandate, supported by paper authorization signed by the debtor.',
    'DDMU': 'DirectDebitUnconfirmedElectronicMandate: Transaction is related to a direct debit instruction authorized under an unconfirmed electronic mandate requiring confirmation by the debtor.',
    'BPA': 'Batch Payments Aruba: Transaction is related to an Instant Credit Transfer under the rules of the Centrale Bank van Aruba, based on the EPC SCT Inst scheme, with a specific batch time-out delay.',
    'IPA': 'Instant Payments Aruba: Transaction is related to an Instant Credit Transfer under the rules of the Centrale Bank van Aruba, based on the EPC SCT Inst scheme.',
    'TRF': 'Credit Transfers: Transaction is related to credit transfers',
    '82': 'Non-pre authorised Direct Debit: Transaction is related to a direct debit that is not pre authorised (Einzugsermächtigung).',
    '83': 'Pre authorised Direct Debit: Transaction is related to a direct debit that is pre authorised (Abbuchungsauftrag).',
    'CPP': 'Cash Per Post: Transaction is related to cash per post. Transaction to ultimate recipient having no bank account. Primary beneficiary is a postal service provider. Funds are paid out by cash. Additional necessary information for address and delivery options need to be attached.',
    'RTR': 'Returned Credit Transfers: Transaction is related to returned credit transfers.',
    'GST': 'Truncated Credit Transfers: Transaction is related to truncated credit transfers. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process..The original instrument rules are retained throughout the life of the instrument. Transaction triggered by specific marked and populated paper slip. Reconciliation reference is secured by check digits supporting secure optical recognition. All other remittance information is truncated prior transmission.',
    'DDT': 'Direct Debits: Transaction is related to direct debits.',
    'RDD': 'Returned Direct Debits: Transaction is related to returned direct debits.',
    'CHN': 'Truncated Checks: Transaction is related to truncated checks. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process..The original instrument rules are retained throughout the life of the instrument.',
    'STR': 'Revoked Credit Transfers: Transaction is related to revoked credit transfers',
    'SDD': 'Revoked Direct Debits: Transaction is related to revoked direct debits.',
    'SRT': 'Revoked Returned Credit Transfers: Transaction is related to revoked returned credit transfers',
    'SRD': 'Revoked Returned Direct Debits: Transaction is related to revoked returned direct debits.',
    'SCN': 'Revoked Truncated Checks: Transaction is related to revoked truncated checks.',
    'SGT': 'Revoked Truncated Credit Transfers: Transaction is related to revoked truncated credit transfers.',
    'CARD': 'Card Clearing: Transaction is related to card clearing.',
    '05': 'Non-pre authorised Direct Debit: Transaction is related to a direct debit that is not pre authorised (Einzugsermächtigung).',
    '04': 'Pre authorised Direct Debit: Transaction is related to a direct debit that is pre authorised (Abbuchungsauftrag).',
    'ISE': 'Image-based Cheque Collection: Transaction is related to the German Image-based Cheque Collection Procedure “Imagegestützter Scheckeinzug - ISE”',
    'BSE': 'Paperless Cheque Collection: Transaction is related to the German Paperless Cheque Collection procedure “Belegloser Scheckeinzug - BSE”',
    'IN': 'Cross Border Customer Credit Transfer: Transaction is related to cross border customers credit transfers',
    '58': 'Business-to-business Direct Debit: Transaction is related to a business-to-business direct debit (CSB58).',
    '19': 'Business-to-customer Direct Debit: Transaction is related to a business-to-customer direct debit (CSB19).',
    'ASTI': 'Ancillary System Transfer Initiation: Indicates that the payment is sent by an authorized third party on behalf of the participant.',
    'BACP': 'Backup Payment: Indicates that the payment was initiated manually using a GUI (Graphical User Interface).',
    'MANP': 'Mandated Payment: Indicates that the payment is sent by responsible Central Bank on behalf of the participant in case of contingency.',
    'SBTI': 'Settlement Bank Transfer Initiation: Indicates that the payment is submitted to move  liquidity to the technical account - dedicated to real-time settlement in an external system (for example ancillary system) . The payment is processed in a separate payment queue besides the normal processing.',
    '85': 'Pre-authorised Direct Debit Accéléré (Accelerated clearing / 2 Day)Ordinaire (Normal clearing / 4 Day): Transaction is related to an urgent direct debit that is pre authorised (Avis de Prélèvement accéléré).',
    '08': 'Pre-authorised Direct Debit Ordinaire (Normal clearing / 4 Day): Transaction is related to a direct debit that is pre authorised (Avis de Prélèvement).',
    '89': 'Pre-authorised Direct Debit Vérifié  (Verified clearing): Transaction is related to an urgent direct debit that is pre authorised (Avis de Prélèvement vérifié).',
    '60': 'Recovered Bill of Exchange or Promissory Note: LCR - Lettre de Change Relevé (Recovered Bill of Exchange) and BOR - Billet à Orde Relevé (Promissory Note)',
    'RIBA': 'Non-pre authorised direct debit: Transaction is related to a non-pre authorised collection (RIBA).',
    'RIDO': 'Pre authorised revocable Direct Debit: Transaction is related to a direct debit that is pre authorised and revocable (RID Ordinario).',
    'RIDV': 'Pre authorised revocable urgent Direct Debit: Transaction is related to an urgent direct debit that is pre authorised and revocable (RID Veloce).',
    'IDEAL': 'Payments via Internet owned by Currence: Transaction is related to payments via internet owned by Currence.',
    'INSTNT01': 'InstantCreditTransferNotTimeCritical: The transaction is related to a regular  Credit Transfer and will be instantly processed under the Dutch AOS on top of the EPC SCT scheme.',
    'INSTTC01': 'InstantCreditTransferTimeCritical: The transaction is related to an Instant Credit Transfer under the rules of the Dutch AOS on top of the EPC SCT Inst scheme.',
    'INSTIDEAL': 'Payments via Internet owned by Currence using Instant Credit Transfer: Transaction is related to payments via internet owned by Currence which uses an Instant Credit Transfer.',
    'INSTNT01IDEAL': 'Payments via Internet owned by Currence using InstantCreditTransferNotTimeCritical: Transaction is related to payments via internet owned by Currence which uses a regular  Credit Transfer and will be instantly processed under the Dutch AOS on top of the EPC SCT scheme.',
    'INSTTC01IDEAL': 'Payments via Internet owned by Currence using InstantCreditTransferTimeCritical: Transaction is related to payments via internet owned by Currence which uses an Instant Credit Transfer under the rules of the Dutch AOS on top of the EPC SCT Inst scheme.',
    'NLDO': 'Dutch Domestic Bulk Payment: Transaction is related to a Domestic payment initiated by PAIN.001',
    'NLUP': 'Dutch Urgent Payment: Transaction is related to a Domestic payment initiated by PAIN.001',
    'ACCEPT': 'Payment via Acceptgiro owned by Currence: Transaction is related to payments via Acceptgiro owned by Currence.',
    'SDN': 'Payments via Standaard Digitale Nota: Transaction is related to payments via a ‘Standaard Digitale Nota’ InvoiceAcceptgiro payment.',
    'ICMC': 'IncidentManagementCorrection: Transaction is related to an Incident Management Correction procedure based on the DD infrastructure.',
    'NLGOV': 'Direct debit initiated by the government with special conditions: Transaction is related to direct debit scheme owned by the NVB.',
    '0090': 'Mass Payment Beneficiary: Transaction is related to mass payment beneficiary.',
    '0091': 'Mass Payment Ours: Transaction is related to mass payment ours.',
    '0092': 'Mass Payment Shared: Transaction is related to mass payment shared.',
    '0002': 'Standing Order: Transaction is related to standing order.',
    '0221': 'One-off Authorisation: Transaction is related to one-off authorisation.',
    '0224': 'One-off Authorisation Charities: Transaction is related to one-off authorisation charities.',
    '0226': 'One-off Authorisation Construction Industry: Transaction is related to one-off authorisation construction industry.',
    '0225': 'One-off Authorisation Tuition Fees: Transaction is related to one-off authorisation tuition fees.',
    '0222': 'Standing Authorisation Companies: Transaction is related to standing authorisation companies.',
    '0227': 'Standing Authorisation Companies Without Debtor Revocation Right: Transaction is related to standing authorisation companies without debtor revocation right.',
    '0220': 'Standing Authorisation General: Transaction is related to standing authorisation general.',
    '0223': 'Standing Authorisation Lotteries: Transaction is related to standing authorisation lotteries.',
    '0001': 'Converted (Bank) Payment: Transaction is related to converted (bank) payment. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process.The instrument rules change upon conversion.',
    '0000': 'Business Payment: Transaction is related to business payment',
    'IN': 'Cross Border Customer Credit Transfer: Transaction is related to cross border customer credit transfer.',
    'ONCL': 'Overnight: Transaction is related to overnight clearing.',
    'PERI': 'PaymentWithERI: Credit transfer contains Extended Remittance Information (ERI) as defined within the applicable scheme.',
    'SDCL': 'Same Day: Transaction is related to same day clearing.',
    'DDNR': 'CoreNoRefund: SEPA Core Direct Debit with ‘no refund’ option',
    'DDFA': 'DirectDebitFixedAmount: SEPA Fixed Amount Direct Debit',
    'CORE': 'SEPA Direct Debit - Core: Transaction is related to SEPA direct debit -core.',
    'B2BAMIPM': 'SEPA B2B Direct Debit AMI: SEPA B2B Direct Debit AMI based on a paper mandate',
    'B2B': 'SEPA Business to Business Direct Debit: Transaction is related to SEPA business to business direct debit.',
    'CR1AMIPM': 'SEPA Core D-1 Direct Debit AMI: Optional shorter time cycle (D-1) for SEPA Core Direct Debit AMI based on a paper mandate',
    'CORAMIPM': 'SEPA Core Direct Debit AMI: SEPA Core Direct Debit AMI based on a paper mandate',
    'COR1': 'SEPA Direct Debit - 1 Day Settlement: Optional shorter time cycle (D-1) for SEPA Core Direct Debit',
    'FADAMIPM': 'SEPA FA Direct Debit AMI: SEPA Fixed Amount Direct Debit AMI based on a paper mandate',
    'INST': 'Instant Credit Transfer: Transaction is related to an Instant Credit Transfer. Use case example: SEPA Instant Credit Transfer (SCT Inst)',
    'ADD': 'AuthenticatedDirectDebit: Transaction is unauthenticated direct debit for domestic use.',
    'UDD': 'UnauthenticatedDirectDebit: Transaction is authenticated direct debit for domestic use.',
    'CCI': 'Cash Concentration Intragroup: Transaction is related to an intra-group bank initiated cash management payment',
    'BTR': 'Bank Transfer: Transaction is related to a bank transfer.',
    'CKS': 'Check Same Day Settlement Wire: Transaction is related to check same day settlement wire.',
    'CTR': 'Customer Transfer: Transaction is related to customer transfer.',
    'CTP': 'Customer Transfer Plus: Transaction is related to a customer transfer, which may include information related to a cover payment or extended remittance information.',
    'DEP': 'Deposit to Sender’s Account: Transaction is related to deposit to sender\'s account.',
    'FFR': 'Fed Funds Returned: Transaction is related to Fed funds returned.',
    'FFS': 'Fed Funds Sold: Transaction is related to Fed funds sold.',
    'SVC': 'Non-Value Service Message: Transaction is related to non-value service message.',
    'DRW': 'Drawdown Response (Value) to Honor a Drawdown Request: Transaction is related to drawdown response (value) to honor a drawdown request.',
    'DRB': 'Bank-to-Bank Drawdown Request or Response (Non-value): Transaction is related to bank-to-bank drawdown request or response (non-value)',
    'DRC': 'Customer or Corporate Drawdown Request or Response (Non-value): Transaction is related to customer or corporate drawdown request or response (non-value).',
    'IAT': 'International ACH: Transaction is related to international ACH.',
    'CCD': 'Cash Concentration or Disbursement Corporate counterparty: Transaction is related to cash concentration or disbursement corporate counterparty.',
    'CTX': 'Corporate Trade Exchange: Transaction is related to corporate trade exchange.',
    'PPD': 'Prearranged Payment or Deposit.  Consumer counterparty: Transaction is related to prearranged payment or deposit consumer counterparty.',
    'CIE': 'Customer Initiated Entry: A credit entry initiated by or on behalf of the holder of a consumer account',
    'RCK': 'Re-presented Check Entry: Transaction is related to re-presented check entry.',
    'ARC': 'Accounts Receivable Check: Transaction is related to accounts receivable check.',
    'WEB': 'Internet Initiated Entry: Transaction is related to internet initiated entry.',
    'POP': 'Point-Of-Purchase: Transaction is related to point-of-purchase.',
    'POS': 'Point-Of-Sale: Transaction is related to point-of-sale.',
    'TEL': 'Telephone Initiated Entry: Transaction is related to telephone initiated entry.',
}

# ExternalMandateReason1Code
MANDATE_REASON = {
    'AC01': 'IncorrectAccountNumber: Format of the account number specified is not correct',
    'AC04': 'ClosedAccountNumber: Account number specified has been closed on the Receiver\'s books',
    'AC06': 'BlockedAccount: Account specified is blocked, prohibiting posting of transactions against it.',
    'AG01': 'TransactionForbidden: Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'InvalidBankOperationCode: Bank Operation code specified in the message is not valid for receiver',
    'AM02': 'NotAllowedAmount: Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'NotAllowedCurrency: Specified message amount is a non processable currency outside of existing agreement',
    'AM05': 'Duplication: Duplication',
    'BE01': 'InconsistenWithEndCustomer: Identification of end customer is not consistent with associated account number. (formerly CreditorConsistency).',
    'BE04': 'MissingCreditorAddress: Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress).',
    'BE05': 'UnrecognisedInitiatingParty: Party who initiated the message is not recognised by the end customer',
    'BE06': 'UnknownEndCustomer: End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'MissingDebtorAddress: Specification of debtor\'s address, which is required for payment, is missing/not correct.',
    'DT01': 'InvalidDate: Invalid date (eg, wrong settlement date)',
    'FF01': 'InvalidFileFormat: File format incomplete or invalid',
    'MD01': 'NoMandate: No Mandate',
    'MD02': 'MissingMandatoryInformationInMandate: Mandate related information data required by the scheme is missing.',
    'MD07': 'EndCustomerDeceased: End customer is deceased.',
    'MD08': 'NoMandateServiceByAgent: Receiving agent does not offer specified Mandate services',
    'MD09': 'NoMandateServiceOnCustomer: Account is not open to specified Mandates services',
    'MD10': 'NoMandateServiceForSpecified: Account is not open to specified Mandates services for this particular creditor',
    'MD11': 'UnrecognisedAgent: Agent to whom the message needs to be forwarded cannot be located',
    'MD12': 'NotUniqueMandateReference: Mandate identification is not unique to the creditor',
    'MD13': 'IncorrectCustomerAuthentication: There is a problem with the customer authentication',
    'MD14': 'IncorrectAgent: Agent in the payment workflow is incorrect',
    'MD15': 'IncorrectCurrency: Currency of the transaction is incorrect',
    'MD16': 'RequestedByCustomer: Cancellation/amendment requested by the debtor',
    'MD17': 'RequestedByInitiatingParty: Cancellation/amendment requested by the creditor',
    'MD18': 'RequestedByInitiatingPartyAndCustomer: Cancellation/amendment requested by the creditor and the debtor',
    'MD19': 'MandateCancelledDueToEarlySettlement: Mandate cancellation following early reimbursement of the debit by the debtor',
    'MD20': 'MandateExpired: Mandate cancellation following validity expiration',
    'MD21': 'MandateCancelledDueToFraud: Mandate cancellation due to suspected fraud',
    'MD22': 'MandateInitiationCancelled: Mandate cancellation following mandate initiation cancellation',
    'MD23': 'MandateAmendmentCancelled: Mandate cancellation following mandate amendment cancellation',
    'MS02': 'NotSpecifiedReasonCustomer Generated: Reason has not been specified by end customer',
    'MS03': 'NotSpecifiedReasonAgentGenerated: Reason has not been specified by agent.',
    'NARR': 'Narrative: Reason is provided as narrative information in the additional reason information.',
    'RC01': 'BankIdentifierIncorrect: Bank Identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode).',
    'RF01': 'NotUniqueTransactionReference: Transaction reference is not unique within the message.',
    'RR01': 'Missing Debtor Account or Identification: Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Missing Debtor Name or Address: Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR03': 'Missing Creditor Name or Address: Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR04': 'Regulatory Reason: Regulatory Reason',
    'SL01': 'Specific Service offered by Debtor Agent: Due to specific service offered by the Debtor Agent',
    'SL11': 'Creditor not on Whitelist of Debtor: Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account.',
    'SL12': 'Creditor on Blacklist of Debtor: Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account.',
    'SL13': 'Maximum number of Direct Debit Transactions exceeded: Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent.',
    'SL14': 'Maximum Direct Debit Transaction Amount exceeded: Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent.',
}

# ExternalOrganisationIdentification1Code
ORGANISATION_IDENTIFICATION = {
    'BANK': 'BankPartyIdentification: Unique and unambiguous assignment made by a specific bank or similar financial institution to identify a relationship as defined between the bank and its client.',
    'CBID': 'Central Bank Identification Number: A unique identification number assigned by a central bank to identify an organisation.',
    'CHID': 'Clearing Identification Number: A unique identification number assigned by a clearing house to identify an organisation',
    'CINC': 'CertificateOfIncorporationNumber: A unique identification number assigned by a designated authority to a certificate of incorporation and used to identify an organisation.',
    'COID': 'CountryIdentificationCode: Country authority given organisation identification (e.g., corporate registration number)',
    'CUST': 'CustomerNumber: Number assigned by an issuer to identify a customer. Number assigned by a party to identify a creditor or debtor relationship.',
    'DUNS': 'Data Universal Numbering System: A unique identification number provided by Dun & Bradstreet to identify an organisation.',
    'EMPL': 'EmployerIdentificationNumber: Number assigned by a registration authority to an employer.',
    'GS1G': 'GS1GLNIdentifier: Global Location Number. A non-significant reference number used to identify legal entities, functional entities, or physical entities according to GS1 numbering scheme rules.The number is used to retrieve detailed information that is linked to it.',
    'SREN': 'SIREN: The SIREN number is a 9 digit code assigned by INSEE, the French National Institute for Statistics and Economic Studies, to identify an organisation in France.',
    'SRET': 'SIRET: The SIRET number is a 14 digit code assigned by INSEE, the French National Institute for Statistics and Economic Studies, to identify an organisation unit in France. It consists of the SIREN number, followed by a five digit classification number, to identify the local geographical unit of that entity',
    'TXID': 'TaxIdentificationNumber: Number assigned by a tax authority to identify an organisation.',
}

# ExternalPersonIdentification1Code
PERSON_IDENTIFICATION = {
    'ARNU': 'AlienRegistrationNumber: Number assigned by a social security agency to identify a non-resident person.',
    'CCPT': 'PassportNumber: Number assigned by an authority to identify the passport number of a person.',
    'CUST': 'CustomerIdentificationNumber: Number assigned by an issuer to identify a customer.',
    'DRLC': 'DriversLicenseNumber: Number assigned by an authority to identify a driver\'s license.',
    'EMPL': 'EmployeeIdentificationNumber: Number assigned by a registration authority to an employee.',
    'NIDN': 'NationalIdentityNumber: Number assigned by an authority to identify the national identity number of a person.',
    'SOSE': 'SocialSecurityNumber: Number assigned by an authority to identify the social security number of a person.',
    'TXID': 'TaxIdentificationNumber: Number assigned by a tax authority to identify a person.',
}

# ExternalPurpose1Code
PURPOSE = {
    'BKDF': 'Bank Debt: Bank Loan Delayed Draw Funding',
    'BKFE': 'Bank Debt: Bank Loan Fees',
    'BKFM': 'Bank Debt: Bank Loan Funding Memo',
    'BKIP': 'Bank Debt: Bank Loan Accrued Interest Payment',
    'BKPP': 'Bank Debt: Bank Loan Principal Paydown',
    'CBLK': 'Card Settlement: Card Bulk Clearing',
    'CDCB': 'Card Settlement: CardPayment with CashBack',
    'CDCD': 'Card Settlement: CashDisbursement',
    'CDCS': 'Card Settlement: Cash Disbursement with Surcharging',
    'CDDP': 'Card Settlement: Card Deferred Payment',
    'CDOC': 'Card Settlement: OriginalCredit',
    'CDQC': 'Card Settlement: QuasiCash',
    'ETUP': 'Card Settlement: E-Purse Top Up',
    'FCOL': 'Card Settlement: Fee Collection',
    'MTUP': 'Card Settlement: Mobile Top Up',
    'ACCT': 'Cash Mgmt: AccountManagement',
    'CASH': 'Cash Mgmt: CashManagementTransfer',
    'COLL': 'Cash Mgmt: CollectionPayment',
    'CSDB': 'Cash Mgmt: CashDisbursement',
    'DEPT': 'Cash Mgmt: Deposit',
    'INTC': 'Cash Mgmt: IntraCompanyPayment',
    'LIMA': 'Cash Mgmt: LiquidityManagement',
    'NETT': 'Cash Mgmt: Netting',
    'BFWD': 'Collateral: Bond Forward',
    'CCIR': 'Collateral: Cross Currency IRS',
    'CCPC': 'Collateral: CCP Cleared Initial Margin',
    'CCPM': 'Collateral: CCP Cleared Variation Margin',
    'CCSM': 'Collateral: CCP Cleared Initial Margin Segregated Cash',
    'CRDS': 'Collateral: Credit DefaultSwap',
    'CRPR': 'Collateral: Cross Product',
    'CRSP': 'Collateral: Credit Support',
    'CRTL': 'Collateral: Credit Line',
    'EQPT': 'Collateral: Equity Option',
    'EQUS': 'Collateral: Equity Swap',
    'EXPT': 'Collateral: Exotic Option',
    'EXTD': 'Collateral: Exchange Traded Derivatives',
    'FIXI': 'Collateral: Fixed Income',
    'FWBC': 'Collateral: Forward Broker Owned Cash Collateral',
    'FWCC': 'Collateral: Forward Client Owned Cash Collateral',
    'FWSB': 'Collateral: Forward Broker Owned Cash Collateral Segregated',
    'FWSC': 'Collateral: Forward Client Owned Segregated Cash Collateral',
    'MARG': 'Collateral: Daily margin on listed derivatives',
    'MBSB': 'Collateral: MBS Broker Owned Cash Collateral',
    'MBSC': 'Collateral: MBS Client Owned Cash Collateral',
    'MGCC': 'Collateral: Futures Initial Margin',
    'MGSC': 'Collateral: Futures Initial Margin Client Owned Segregated Cash Collateral',
    'OCCC': 'Collateral: Client owned OCC pledged collateral',
    'OPBC': 'Collateral: OTC Option Broker owned Cash collateral',
    'OPCC': 'Collateral: OTC Option Client owned Cash collateral',
    'OPSB': 'Collateral: OTC Option Broker Owned Segregated Cash Collateral',
    'OPSC': 'Collateral: OTC Option Client Owned Cash Segregated Cash Collateral',
    'OPTN': 'Collateral: FX Option',
    'OTCD': 'Collateral: OTC Derivatives',
    'REPO': 'Collateral: Repurchase Agreement',
    'RPBC': 'Collateral: Bi-lateral repo broker owned collateral',
    'RPCC': 'Collateral: Repo client owned collateral',
    'RPSB': 'Collateral: Bi-lateral repo broker owned segregated cash collateral',
    'RPSC': 'Collateral: Bi-lateral Repo client owned segregated cash collateral',
    'RVPO': 'Collateral: Reverse Repurchase Agreement',
    'SBSC': 'Collateral: Securities Buy Sell Sell Buy Back',
    'SCIE': 'Collateral: Single Currency IRS Exotic',
    'SCIR': 'Collateral: Single Currency IRS',
    'SCRP': 'Collateral: Securities Cross Products',
    'SHBC': 'Collateral: Broker owned collateral Short Sale',
    'SHCC': 'Collateral: Client owned collateral Short Sale',
    'SHSL': 'Collateral: Short Sell',
    'SLEB': 'Collateral: Securities Lending And Borrowing',
    'SLOA': 'Collateral: SecuredLoan',
    'SWBC': 'Collateral: Swap Broker owned cash collateral',
    'SWCC': 'Collateral: Swap Client owned cash collateral',
    'SWPT': 'Collateral: Swaption',
    'SWSB': 'Collateral: Swaps Broker Owned Segregated Cash Collateral',
    'SWSC': 'Collateral: Swaps Client Owned Segregated Cash Collateral',
    'TBAS': 'Collateral: To Be Announced',
    'TBBC': 'Collateral: TBA Broker owned cash collateral',
    'TBCC': 'Collateral: TBA Client owned cash collateral',
    'TRCP': 'Collateral: Treasury Cross Product',
    'AGRT': 'Commercial: AgriculturalTransfer',
    'AREN': 'Commercial: Accounts Receivables Entry',
    'BEXP': 'Commercial: BusinessExpenses',
    'BOCE': 'Commercial: Back Office Conversion Entry',
    'COMC': 'Commercial: CommercialPayment',
    'CPYR': 'Commercial: Copyright',
    'GDDS': 'Commercial: PurchaseSaleOfGoods',
    'GDSV': 'Commercial: PurchaseSaleOfGoodsAndServices',
    'GSCB': 'Commercial: PurchaseSaleOfGoodsAndServicesWithCashBack',
    'LICF': 'Commercial: LicenseFee',
    'MP2B': 'Commercial: Mobile P2B Payment',
    'POPE': 'Commercial: Point of Purchase Entry',
    'ROYA': 'Commercial: Royalties',
    'SCVE': 'Commercial: PurchaseSaleOfServices',
    'SERV': 'Commercial: Service Charges',
    'SUBS': 'Commercial: Subscription',
    'SUPP': 'Commercial: SupplierPayment',
    'TRAD': 'Commercial: Commercial',
    'CHAR': 'Consumer: CharityPayment',
    'COMT': 'Consumer: ConsumerThirdPartyConsolidatedPayment',
    'MP2P': 'Consumer: Mobile P2P Payment',
    'ECPG': 'E-Commerce: GuaranteedEPayment',
    'ECPR': 'E-Commerce: EPaymentReturn',
    'ECPU': 'E-Commerce: NonGuaranteedEPayment',
    'EPAY': 'E-Commerce: Epayment',
    'CLPR': 'Finance: CarLoanPrincipalRepayment',
    'COMP': 'Finance: Compensation Payment',
    'DBTC': 'Finance: DebitCollectionPayment',
    'GOVI': 'Finance: GovernmentInsurance',
    'HLRP': 'Finance: HousingLoanRepayment',
    'HLST': 'Finance: Home Loan Settlement',
    'INPC': 'Finance: InsurancePremiumCar',
    'INPR': 'Finance: Insurance Premium Refund',
    'INSC': 'Finance: Payment of Insurance Claim',
    'INSU': 'Finance: InsurancePremium',
    'INTE': 'Finance: Interest',
    'LBRI': 'Finance: LaborInsurance',
    'LIFI': 'Finance: LifeInsurance',
    'LOAN': 'Finance: Loan',
    'LOAR': 'Finance: LoanRepayment',
    'PENO': 'Finance: PaymentBasedOnEnforcementOrder',
    'PPTI': 'Finance: PropertyInsurance',
    'RELG': 'Finance: RentalLeaseGeneral',
    'RINP': 'Finance: RecurringInstallmentPayment',
    'TRFD': 'Finance: TrustFund',
    'FORW': 'Foreign Exchange: Forward Foreign Exchange',
    'FXNT': 'Foreign Exchange: Foreign Exchange Related Netting',
    'ADMG': 'General: AdministrativeManagement',
    'ADVA': 'General: AdvancePayment',
    'BCDM': 'General: BearerChequeDomestic',
    'BCFG': 'General: BearerChequeForeign',
    'BLDM': 'General: BuildingMaintenance',
    'BNET': 'General: Bond Forward Netting',
    'CBFF': 'General: CapitalBuilding',
    'CBFR': 'General: CapitalBuildingRetirement',
    'CCRD': 'General: CreditCardPayment',
    'CDBL': 'General: CreditCardBill',
    'CFEE': 'General: CancellationFee',
    'CGDD': 'General: CardGeneratedDirectDebit',
    'CORT': 'General: Trade Settlement Payment',
    'COST': 'General: Costs',
    'CPKC': 'General: Carpark Charges',
    'DCRD': 'General: Debit Card Payment',
    'DSMT': 'General: Printed Order Disbursement',
    'DVPM': 'General: Deliver Against Payment',
    'EDUC': 'General: Education',
    'FACT': 'General: Factor Update related payment',
    'FAND': 'General: FinancialAidInCaseOfNaturalDisaster',
    'FCPM': 'General: Late Payment of Fees & Charges',
    'FEES': 'General: Payment of Fees',
    'GOVT': 'General: GovernmentPayment',
    'ICCP': 'General: IrrevocableCreditCardPayment',
    'IDCP': 'General: IrrevocableDebitCardPayment',
    'IHRP': 'General: InstalmentHirePurchaseAgreement',
    'INSM': 'General: Installment',
    'IVPT': 'General: Invoice Payment',
    'MCDM': 'General: MultiCurrenyChequeDomestic',
    'MCFG': 'General: MultiCurrenyChequeForeign',
    'MSVC': 'General: MultipleServiceTypes',
    'NOWS': 'General: NotOtherwiseSpecified',
    'OCDM': 'General: OrderChequeDomestic',
    'OCFG': 'General: OrderChequeForeign',
    'OFEE': 'General: OpeningFee',
    'OTHR': 'General: Other',
    'PADD': 'General: Preauthorized debit',
    'PTSP': 'General: PaymentTerms',
    'RCKE': 'General: Re-presented Check Entry',
    'RCPT': 'General: ReceiptPayment',
    'REBT': 'General: Rebate',
    'REFU': 'General: Refund',
    'RENT': 'General: Rent',
    'REOD': 'General: AccountOverdraftRepayment',
    'RIMB': 'General: Reimbursement of a previous erroneous transaction',
    'RPNT': 'General: Bi-lateral repo internet netting',
    'RRBN': 'General: Round Robin',
    'RRCT': 'General: ReimbursementReceivedCreditTransfer',
    'RVPM': 'General: Receive Against Payment',
    'SLPI': 'General: PaymentSlipInstruction',
    'SPLT': 'General: Split payments',
    'STDY': 'General: Study',
    'TBAN': 'General: TBA pair-off netting',
    'TBIL': 'General: Telecommunications Bill',
    'TCSC': 'General: Town Council Service Charges',
    'TELI': 'General: Telephone-Initiated Transaction',
    'TMPG': 'General: TMPG claim payment',
    'TPRI': 'General: Tri Party Repo Interest',
    'TPRP': 'General: Tri-party Repo netting',
    'TRNC': 'General: TruncatedPaymentSlip',
    'TRVC': 'General: TravellerCheque',
    'WEBI': 'General: Internet-Initiated Transaction',
    'IPAY': 'Instant Payments: Instant Payments',
    'IPCA': 'Instant Payments: Instant Payments cancellation',
    'IPDO': 'Instant Payments: Instant Payments for donations',
    'IPEA': 'Instant Payments: Instant Payments in E-Commerce without address data',
    'IPEC': 'Instant Payments: Instant Payments in E-Commerce with address data',
    'IPEW': 'Instant Payments: Instant Payments in E-Commerce',
    'IPPS': 'Instant Payments: Instant Payments at POS',
    'IPRT': 'Instant Payments: Instant Payments return',
    'IPU2': 'Instant Payments: Instant Payments unattended vending machine with 2FA',
    'IPUW': 'Instant Payments: Instant Payments unattended vending machine without 2FA',
    'ANNI': 'Investment: Annuity',
    'CAFI': 'Investment: Custodian Management fee In-house',
    'CFDI': 'Investment: Capital falling due In-house',
    'CMDT': 'Investment: CommodityTransfer',
    'DERI': 'Investment: Derivatives',
    'DIVD': 'Investment: Dividend',
    'FREX': 'Investment: ForeignExchange',
    'HEDG': 'Investment: Hedging',
    'INVS': 'Investment: Investment & Securities',
    'PRME': 'Investment: PreciousMetal',
    'SAVG': 'Investment: Savings',
    'SECU': 'Investment: Securities',
    'SEPI': 'Investment: Securities Purchase In-house',
    'TREA': 'Investment: TreasuryPayment',
    'UNIT': 'Investment: UnitTrustPurchase',
    'FNET': 'Listed Derivatives: Futures Netting Payment',
    'FUTR': 'Listed Derivatives: Futures',
    'ANTS': 'Medical: AnesthesiaServices',
    'CVCF': 'Medical: ConvalescentCareFacility',
    'DMEQ': 'Medical: DurableMedicaleEquipment',
    'DNTS': 'Medical: DentalServices',
    'HLTC': 'Medical: HomeHealthCare',
    'HLTI': 'Medical: HealthInsurance',
    'HSPC': 'Medical: HospitalCare',
    'ICRF': 'Medical: IntermediateCareFacility',
    'LTCF': 'Medical: LongTermCareFacility',
    'MAFC': 'Medical: MedicalAidFundContribution',
    'MARF': 'Medical: Medical Aid Refund',
    'MDCS': 'Medical: MedicalServices',
    'VIEW': 'Medical: VisionCare',
    'CDEP': 'OTC Derivatives: Credit default event payment',
    'SWFP': 'OTC Derivatives: Swap contract final payment',
    'SWPP': 'OTC Derivatives: Swap contract partial payment',
    'SWRS': 'OTC Derivatives: Swap contract reset payment',
    'SWUF': 'OTC Derivatives: Swap contract upfront payment',
    'ADCS': 'Salary & Benefits: AdvisoryDonationCopyrightServices',
    'AEMP': 'Salary & Benefits: ActiveEmploymentPolicy',
    'ALLW': 'Salary & Benefits: Allowance',
    'ALMY': 'Salary & Benefits: AlimonyPayment',
    'BBSC': 'Salary & Benefits: Baby Bonus Scheme',
    'BECH': 'Salary & Benefits: ChildBenefit',
    'BENE': 'Salary & Benefits: UnemploymentDisabilityBenefit',
    'BONU': 'Salary & Benefits: BonusPayment.',
    'CCHD': 'Salary & Benefits: Cash compensation, Helplessness, Disability',
    'COMM': 'Salary & Benefits: Commission',
    'CSLP': 'Salary & Benefits: CompanySocialLoanPaymentToBank',
    'GFRP': 'Salary & Benefits: GuaranteeFundRightsPayment',
    'GVEA': 'Salary & Benefits: Austrian Government Employees Category A',
    'GVEB': 'Salary & Benefits: Austrian Government Employees Category B',
    'GVEC': 'Salary & Benefits: Austrian Government Employees Category C',
    'GVED': 'Salary & Benefits: Austrian Government Employees Category D',
    'GWLT': 'Salary & Benefits: GovermentWarLegislationTransfer',
    'HREC': 'Salary & Benefits: Housing Related Contribution',
    'PAYR': 'Salary & Benefits: Payroll',
    'PEFC': 'Salary & Benefits: PensionFundContribution',
    'PENS': 'Salary & Benefits: PensionPayment',
    'PRCP': 'Salary & Benefits: PricePayment',
    'RHBS': 'Salary & Benefits: RehabilitationSupport',
    'SALA': 'Salary & Benefits: SalaryPayment',
    'SPSP': 'Salary & Benefits: SalaryPensionSumPayment',
    'SSBE': 'Salary & Benefits: SocialSecurityBenefit',
    'LBIN': 'Securities Lending: Lending Buy-In Netting',
    'LCOL': 'Securities Lending: Lending Cash Collateral Free Movement',
    'LFEE': 'Securities Lending: Lending Fees',
    'LMEQ': 'Securities Lending: Lending Equity marked-to-market  cash collateral',
    'LMFI': 'Securities Lending: Lending Fixed Income marked-to-market cash collateral',
    'LMRK': 'Securities Lending: Lending unspecified type of marked-to-market cash collateral',
    'LREB': 'Securities Lending: Lending rebate payments',
    'LREV': 'Securities Lending: Lending Revenue Payments',
    'LSFL': 'Securities Lending: Lending Claim Payment',
    'ESTX': 'Tax: EstateTax',
    'FWLV': 'Tax: Foreign Worker Levy',
    'GSTX': 'Tax: Goods & Services Tax',
    'HSTX': 'Tax: HousingTax',
    'INTX': 'Tax: IncomeTax',
    'NITX': 'Tax: NetIncomeTax',
    'PTXP': 'Tax: Property Tax',
    'RDTX': 'Tax: Road Tax',
    'TAXS': 'Tax: TaxPayment',
    'VATX': 'Tax: ValueAddedTaxPayment',
    'WHLD': 'Tax: WithHolding',
    'TAXR': 'Tax: TaxRefund',
    'B112': 'Trailer Fee: Trailer Fee Payment',
    'BR12': 'Trailer Fee: Trailer Fee Rebate',
    'TLRF': 'Trailer Fee: Non-US mutual fund trailer fee payment',
    'TLRR': 'Trailer Fee: Non-US mutual fund trailer fee rebate payment',
    'AIRB': 'Transport: Air',
    'BUSB': 'Transport: Bus',
    'FERB': 'Transport: Ferry',
    'RLWY': 'Transport: Railway',
    'TRPT': 'Transport: RoadPricing',
    'CBTV': 'Utilities: CableTVBill',
    'ELEC': 'Utilities: ElectricityBill',
    'ENRG': 'Utilities: Energies',
    'GASB': 'Utilities: GasBill',
    'NWCH': 'Utilities: NetworkCharge',
    'NWCM': 'Utilities: NetworkCommunication',
    'OTLC': 'Utilities: OtherTelecomRelatedBill',
    'PHON': 'Utilities: TelephoneBill',
    'UBIL': 'Utilities: Utilities',
    'WTER': 'Utilities: WaterBill',
}

# ExternalReportingSource1Code
REPORTING_SOURCE = {
    'ACCT': 'Accounting: Statement or Report is based on accounting data.',
    'ARPF': 'Account Reconciliation System - Full: An account reconciliation system that provides full reconciliation that usually addresses checks',
    'ARPP': 'Account Reconciliation System - Partial: An account reconciliation system that provides partial reconciliation that usually addresses checks',
    'CTDB': 'Controlled Disbursement System: A sub-application that reports presentment totals',
    'CUST': 'Custody: Statement or Report is based on custody data.',
    'DEPT': 'Deposit System: Cash or deposit accounting system',
    'DPCS': 'Deposit Concentration System: Deposit system that reports what has been collected from various financial institutions',
    'LKBX': 'Lockbox: Processing system that captures and reports check data in a lockbox environment.',
    'RCPT': 'Receipts: A system that reports consolidated remittance information obtained from various , i.e., ACH, wires, lockbox, etc.',
}

# ExternalReturnReason1Code
RETURN_REASON = {
    'AC01': 'IncorrectAccountNumber: Format of the account number specified is not correct',
    'AC03': 'InvalidCreditorAccountNumber: Wrong IBAN in SCT',
    'AC04': 'ClosedAccountNumber: Account number specified has been closed on the bank of account\'s books',
    'AC06': 'BlockedAccount: Account specified is blocked, prohibiting posting of transactions against it.',
    'AC13': 'InvalidDebtorAccountType: Debtor account type is missing or invalid',
    'AC14': 'InvalidAgent: An agent in the payment chain is invalid.',
    'AC15': 'AccountDetailsChanged: Account details have changed.',
    'AC16': 'AccountInSequestration: Account is in sequestration.',
    'AC17': 'AccountInLiquidation: Account is in liquidation.',
    'AG01': 'TransactionForbidden: Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'InvalidBankOperationCode: Bank Operation code specified in the message is not valid for receiver',
    'AM01': 'ZeroAmount: Specified message amount is equal to zero',
    'AM02': 'NotAllowedAmount: Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'NotAllowedCurrency: Specified message amount is an non processable currency outside of existing agreement',
    'AM04': 'InsufficientFunds: Amount of funds available to cover specified message amount is insufficient.',
    'AM05': 'Duplication: Duplication',
    'AM06': 'TooLowAmount: Specified transaction amount is less than agreed minimum.',
    'AM07': 'BlockedAmount: Amount of funds available to cover specified message amount is insufficient.',
    'AM09': 'WrongAmount: Amount received is not the amount agreed or expected',
    'AM10': 'InvalidControlSum: Sum of instructed amounts does not equal the control sum.',
    'ARDT': 'AlreadyReturnedTransaction: Already returned original SCT',
    'BE01': 'InconsistenWithEndCustomer: Identification of end customer is not consistent with associated account number (formerly CreditorConsistency).',
    'BE04': 'MissingCreditorAddress: Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress).',
    'BE05': 'UnrecognisedInitiatingParty: Party who initiated the message is not recognised by the end customer',
    'BE06': 'UnknownEndCustomer: End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'MissingDebtorAddress: Specification of debtor\'s address, which is required for payment, is missing/not correct.',
    'BE08': 'BankError: Returned as a result of a bank error.',
    'CN01': 'AuthorisationCancelled: Authorisation is cancelled.',
    'CNOR': 'Creditor bank is not registered: Creditor bank is not registered under this BIC in the CSM',
    'CURR': 'IncorrectCurrency: Currency of the payment is incorrect',
    'CUST': 'RequestedByCustomer: Cancellation requested by the Debtor',
    'DNOR': 'Debtor bank is not registered: Debtor bank is not registered under this BIC in the CSM',
    'DS28': 'ReturnForTechnicalReason: Return following technical problems resulting in erroneous transaction.',
    'DT01': 'InvalidDate: Invalid date (eg, wrong settlement date)',
    'ED01': 'CorrespondentBankNotPossible: Correspondent bank not possible.',
    'ED03': 'BalanceInfoRequest: Balance of payments complementary info is requested',
    'ED05': 'SettlementFailed: Settlement of the transaction has failed.',
    'EMVL': 'EMV Liability Shift: The card payment is fraudulent and was not processed with EMV technology for an EMV card.',
    'ERIN': 'ERIOptionNotSupported: The Extended Remittance Information (ERI) option is not supported.',
    'FF05': 'InvalidLocalInstrumentCode: Local Instrument code is missing or invalid',
    'FOCR': 'FollowingCancellationRequest: Return following a cancellation request',
    'FR01': 'Fraud: Returned as a result of fraud.',
    'FRTR': 'FinalResponseMandateCancelled: Final response/tracking is recalled as mandate is cancelled.',
    'MD01': 'NoMandate: No Mandate',
    'MD02': 'MissingMandatoryInformationIn Mandate: Mandate related information data required by the scheme is missing.',
    'MD06': 'RefundRequestByEndCustomer: Return of funds requested by end customer',
    'MD07': 'EndCustomerDeceased: End customer is deceased.',
    'MS02': 'NotSpecifiedReasonCustomer Generated: Reason has not been specified by end customer',
    'MS03': 'NotSpecifiedReasonAgent     Generated: Reason has not been specified by agent.',
    'NARR': 'Narrative: Reason is provided as narrative information in the additional reason information.',
    'NOAS': 'NoAnswerFromCustomer: No response from Beneficiary',
    'NOCM': 'NotCompliant: Customer account is not compliant with regulatory requirements, for example FICA (in South Africa) or any other regulatory requirements which render an account inactive for certain processing.',
    'NOOR': 'NoOriginalTransactionReceived: Original SCT never received',
    'PINL': 'PIN Liability Shift: The card payment is fraudulent (lost and stolen fraud) and was processed as EMV transaction without PIN verification.',
    'RC01': 'BankIdentifierIncorrect: Bank Identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode).',
    'RC07': 'InvalidCreditorBICIdentifier: Incorrrect BIC of the beneficiary Bank in the SCTR',
    'RF01': 'NotUniqueTransactionReference: Transaction reference is not unique within the message.',
    'RR01': 'Missing Debtor Account or Identification: Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Missing Debtor Name or Address: Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR03': 'Missing Creditor Name or Address: Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR04': 'Regulatory Reason: Regulatory Reason',
    'RUTA': 'ReturnUponUnableToApply: Return following investigation request and no remediation possible.',
    'SL01': 'Specific Service offered by Debtor Agent: Due to specific service offered by the Debtor Agent',
    'SL02': 'Specific Service offered by Creditor Agent: Due to specific service offered by the Creditor Agent',
    'SL11': 'Creditor not on Whitelist of Debtor: Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account.',
    'SL12': 'Creditor on Blacklist of Debtor: Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account.',
    'SL13': 'Maximum number of Direct Debit Transactions exceeded: Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent.',
    'SL14': 'Maximum Direct Debit Transaction Amount exceeded: Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent.',
    'SP01': 'PaymentStopped: Payment is stopped by account holder.',
    'SP02': 'PreviouslyStopped: Previously stopped by means of a stop payment advise.',
    'SVNR': 'ServiceNotRendered: The card payment is returned since a cash amount rendered was not correct or goods or a service was not rendered to the customer, e.g. in an e-commerce situation.',
    'TM01': 'CutOffTime: Associated message was received after agreed processing cut-off time.',
    'TRAC': 'RemovedFromTracking: Return following direct debit being removed from tracking process.',
    'UPAY': 'UnduePayment: Payment is not justified.',
}

# ExternalReversalReason1Code
REVERSAL_REASON = {
    'AC03': 'InvalidCreditorAccountNumber: Wrong IBAN in  SCT',
    'AC04': 'ClosedAccountNumber: Account number specified has been closed on the Receiver\'s books',
    'AG02': 'InvalidBankOperationCode: Bank Operation code specified in the message is not valid for receiver',
    'AM05': 'Duplication: Duplication',
    'AM09': 'WrongAmount: Wrong amount in SCT',
    'MD01': 'NoMandate: No Mandate',
    'MD05': 'CollectionNotDue: Creditor or creditor\'s agent should not have collected the direct debit',
    'MS02': 'NotSpecifiedReasonCustomerGenerated: Reason has not been specified by end customer',
    'MS03': 'NotSpecifiedReasonAgentGenerated: Reason has not been specified by agent.',
    'RC07': 'InvalidCreditorBICIdentifier: Wrong BIC in SCT',
    'TM01': 'CutOffTime: Associated message was received after agreed processing cut-off time.',
}

# ExternalServiceLevel1Code
SERVICE_LEVEL = {
    'BKTR': 'Book Transaction: Payment through internal book transfer.',
    'G001': 'TrackedCustomerCreditTransfer: Tracked Customer Credit Transfer',
    'G002': 'TrackedStopAndRecall: Tracked Stop and Recall',
    'G003': 'TrackedCorporateTransfer: Tracked Corporate Transfer',
    'G004': 'TrackedFinancialInstitutionTransfer: Tracked Financial Institution Transfer',
    'NUGP': 'Non-urgent Priority Payment: Payment must be executed as a non-urgent transaction with priority settlement.',
    'NURG': 'Non-urgent Payment: Payment must be executed as a non-urgent transaction, which is typically identified as an ACH or low value transaction.',
    'PRPT': 'EBAPriorityService: Transaction must be processed according to the EBA Priority Service.',
    'SDVA': 'SameDayValue: Payment must be executed with same day value to the creditor.',
    'SEPA': 'SingleEuroPaymentsArea: Payment must be executed following the Single Euro Payments Area scheme.',
    'SVDE': 'Domestic Cheque Clearing and Settlement: Payment execution following the cheque agreement and traveller cheque agreement of the German Banking Industry Committee (Die Deutsche Kreditwirtschaft - DK) and Deutsche Bundesbank – Scheck Verrechnung Deutschland',
    'URGP': 'Urgent Payment: Payment must be executed as an urgent transaction cleared through a real-time gross settlement system, which is typically identified as a wire or high value transaction.',
    'URNS': 'Urgent Payment Net Settlement: Payment must be executed as an urgent transaction cleared through a real-time net settlement system, which is typically identified as a wire or high value transaction.',
}

# ExternalStatusReason1Code
STATUS_REASON = {
    'AB01': 'AbortedClearingTimeout: Clearing process aborted due to timeout.',
    'AB02': 'AbortedClearingFatalError: Clearing process aborted due to a fatal error.',
    'AB03': 'AbortedSettlementTimeout: Settlement aborted due to timeout.',
    'AB04': 'AbortedSettlementFatalError: Settlement process aborted due to a fatal error.',
    'AB05': 'TimeoutCreditorAgent: Transaction stopped due to timeout at the Creditor Agent.',
    'AB06': 'TimeoutInstructedAgent: Transaction stopped due to timeout at the Instructed Agent.',
    'AB07': 'OfflineAgent: Agent of message is not online. Generic usage if it cannot be determined who exactly is not online.',
    'AB08': 'OfflineCreditorAgent: Creditor Agent is not online.',
    'AB09': 'ErrorCreditorAgent: Transaction stopped due to error at the Creditor Agent.',
    'AB10': 'ErrorInstructedAgent: Transaction stopped due to error at the Instructed Agent.',
    'AC01': 'IncorrectAccountNumber: Account number is invalid or missing.',
    'AC02': 'InvalidDebtorAccountNumber: Debtor account number invalid or missing',
    'AC03': 'InvalidCreditorAccountNumber: Creditor account number invalid or missing',
    'AC04': 'ClosedAccountNumber: Account number specified has been closed on the bank of account\'s books.',
    'AC05': 'ClosedDebtorAccountNumber: Debtor account number closed',
    'AC06': 'BlockedAccount: Account specified is blocked, prohibiting posting of transactions against it.',
    'AC07': 'ClosedCreditorAccountNumber: Creditor account number closed',
    'AC08': 'InvalidBranchCode: Branch code is invalid or missing',
    'AC09': 'InvalidAccountCurrency: Account currency is invalid or missing',
    'AC10': 'InvalidDebtorAccountCurrency: Debtor account currency is invalid or missing',
    'AC11': 'InvalidCreditorAccountCurrency: Creditor account currency is invalid or missing',
    'AC12': 'InvalidAccountType: Account type missing or invalid. Generic usage if cannot specify between group and payment information levels',
    'AC13': 'InvalidDebtorAccountType: Debtor account type missing or invalid',
    'AC14': 'InvalidCreditorAccountType: Creditor account type missing or invalid',
    'AC15': 'AccountDetailsChanged: The account details for the counterparty have changed.',
    'AG01': 'TransactionForbidden: Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'InvalidBankOperationCode: Bank Operation code specified in the message is not valid for receiver',
    'AG03': 'TransactionNotSupported: Transaction type not supported/authorized on this account',
    'AG04': 'InvalidAgentCountry: Agent country code is missing or invalid. Generic usage if cannot specify between group and payment information levels.',
    'AG05': 'InvalidDebtorAgentCountry: Debtor agent country code is missing or invalid',
    'AG06': 'InvalidCreditorAgentCountry: Creditor agent country code is missing or invalid',
    'AG07': 'UnsuccesfulDirectDebit: Debtor account cannot be debited for a generic reason. Code value may be used in general purposes and as a replacement for AM04 if debtor bank does not reveal its customer\'s insufficient funds for privacy reasons',
    'AG08': 'InvalidAccessRights: Transaction failed due to invalid or missing user or access right',
    'AG09': 'PaymentNotReceived: Original payment never received.',
    'AG10': 'AgentSuspended: Agent of message is suspended from the Real Time Payment system. Generic usage if it cannot be determined who exactly is suspended.',
    'AG11': 'CreditorAgentSuspended: Creditor Agent of message is suspended from the Real Time Payment system.',
    'AGNT': 'IncorrectAgent: Agent in the payment workflow is incorrect',
    'AM01': 'ZeroAmount: Specified message amount is equal to zero',
    'AM02': 'NotAllowedAmount: Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'NotAllowedCurrency: Specified message amount is an non processable currency outside of existing agreement',
    'AM04': 'InsufficientFunds: Amount of funds available to cover specified message amount is insufficient.',
    'AM05': 'Duplication: Duplication',
    'AM06': 'TooLowAmount: Specified transaction amount is less than agreed minimum.',
    'AM07': 'BlockedAmount: Amount of funds available to cover specified message amount is insufficient.',
    'AM09': 'WrongAmount: Amount received is not the amount agreed or expected',
    'AM10': 'InvalidControlSum: Sum of instructed amounts does not equal the control sum.',
    'AM11': 'InvalidTransactionCurrency: Transaction currency is invalid or missing',
    'AM12': 'InvalidAmount: Amount is invalid or missing',
    'AM13': 'AmountExceedsClearingSystemLimit: Transaction amount exceeds limits set by clearing system',
    'AM14': 'AmountExceedsAgreedLimit: Transaction amount exceeds limits agreed between bank and client',
    'AM15': 'AmountBelowClearingSystemMinimum: Transaction amount below minimum set by clearing system',
    'AM16': 'InvalidGroupControlSum: Control Sum at the Group level is invalid',
    'AM17': 'InvalidPaymentInfoControlSum: Control Sum at the Payment Information level is invalid',
    'AM18': 'InvalidNumberOfTransactions: Number of transactions is invalid or missing. Generic usage if cannot specify between group and payment information levels.',
    'AM19': 'InvalidGroupNumberOfTransactions: Number of transactions at the Group level is invalid or missing',
    'AM20': 'InvalidPaymentInfoNumberOfTransactions: Number of transactions at the Payment Information level is invalid',
    'AM21': 'LimitExceeded: Transaction amount exceeds limits agreed between bank and client.',
    'AM22': 'ZeroAmountNotApplied: Unable to apply zero amount to designated account. For example, where the rules of a service allow the use of zero amount payments, however the back-office system is unable to apply the funds to the account. If the rules of a service prohibit the use of zero amount payments, then code AM01 is used to report the error condition.',
    'AM23': 'AmountExceedsSettlementLimit: Transaction amount exceeds settlement limit.',
    'BE01': 'InconsistenWithEndCustomer: Identification of end customer is not consistent with associated account number. (formerly CreditorConsistency).',
    'BE04': 'MissingCreditorAddress: Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress).',
    'BE05': 'UnrecognisedInitiatingParty: Party who initiated the message is not recognised by the end customer',
    'BE06': 'UnknownEndCustomer: End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'MissingDebtorAddress: Specification of debtor\'s address, which is required for payment, is missing/not correct.',
    'BE08': 'MissingDebtorName: Debtor name is missing',
    'BE09': 'InvalidCountry: Country code is missing or Invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE10': 'InvalidDebtorCountry: Debtor country code is missing or invalid',
    'BE11': 'InvalidCreditorCountry: Creditor country code is missing or invalid',
    'BE12': 'InvalidCountryOfResidence: Country code of residence is missing or Invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE13': 'InvalidDebtorCountryOfResidence: Country code of debtor\'s residence is missing or Invalid',
    'BE14': 'InvalidCreditorCountryOfResidence: Country code of creditor\'s residence is missing or Invalid',
    'BE15': 'InvalidIdentificationCode: Identification code missing or invalid. Generic usage if cannot specifically identify debtor or creditor.',
    'BE16': 'InvalidDebtorIdentificationCode: Debtor or Ultimate Debtor identification code missing or invalid',
    'BE17': 'InvalidCreditorIdentificationCode: Creditor or Ultimate Creditor identification code missing or invalid',
    'BE18': 'InvalidContactDetails: Contact details missing or invalid',
    'BE19': 'InvalidChargeBearerCode: Charge bearer code for transaction type is invalid',
    'BE20': 'InvalidNameLength: Name length exceeds local rules for payment type.',
    'BE21': 'MissingName: Name missing or invalid.  Generic usage if cannot specifically identify debtor or creditor.',
    'BE22': 'MissingCreditorName: Creditor name is missing',
    'CERI': 'CheckERI: Credit transfer is not tagged as an Extended Remittance Information (ERI) transaction but contains ERI.',
    'CH03': 'RequestedExecutionDateOrRequestedCollectionDateTooFarInFuture: Value in Requested Execution Date or Requested Collection Date is too far in the future',
    'CH04': 'RequestedExecutionDateOrRequestedCollectionDateTooFarInPast: Value in Requested Execution Date or Requested Collection Date is too far in the past',
    'CH07': 'ElementIsNotToBeUsedAtB-andC-Level: Element is not to be used at B- and C-Level',
    'CH09': 'MandateChangesNotAllowed: Mandate changes are not allowed',
    'CH10': 'InformationOnMandateChangesMissing: Information on mandate changes are missing',
    'CH11': 'CreditorIdentifierIncorrect: Value in Creditor Identifier is incorrect',
    'CH12': 'CreditorIdentifierNotUnambiguouslyAtTransaction-Level: Creditor Identifier is ambiguous at Transaction Level',
    'CH13': 'OriginalDebtorAccountIsNotToBeUsed: Original Debtor Account is not to be used',
    'CH14': 'OriginalDebtorAgentIsNotToBeUsed: Original Debtor Agent  is not to be used',
    'CH15': 'ElementContentIncludesMoreThan140Charac­ters: Content Remittance Information/Structured includes more than 140 characters',
    'CH16': 'ElementContentFormallyIncorrect: Content is incorrect',
    'CH17': 'ElementNotAdmitted: Element is not allowed',
    'CH19': 'ValuesWillBeSetToNextTARGETday: Values in Interbank Settlement Date or Requested Collection Date will be set to the next TARGET day',
    'CH20': 'DecimalPointsNotCompatibleWithCurrency: Number of decimal points not compatible with the currency',
    'CH21': 'RequiredCompulsoryElementMissing: Mandatory element is missing',
    'CH22': 'COREandB2BwithinOnemessage: SDD CORE and B2B not permitted within one message',
    'CNOR': 'Creditor bank is not registered: Creditor bank is not registered under this BIC in the CSM',
    'CURR': 'IncorrectCurrency: Currency of the payment is incorrect',
    'CUST': 'RequestedByCustomer: Cancellation requested by the Debtor',
    'DNOR': 'Debtor bank is not registered: Debtor bank is not registered under this BIC in the CSM',
    'DS01': 'ElectronicSignaturesCorrect: The electronic signature(s) is/are correct',
    'DS02': 'OrderCancelled: An authorized user has cancelled the order',
    'DS03': 'OrderNotCancelled: The user’s attempt to cancel the order was not successful',
    'DS04': 'OrderRejected: The order was rejected by the bank side (for reasons concerning content)',
    'DS05': 'OrderForwardedForPostprocessing: The order was correct and could be forwarded for postprocessing',
    'DS06': 'TransferOrder: The order was transferred to VEU',
    'DS07': 'ProcessingOK: All actions concerning the order could be done by the EBICS bank server',
    'DS08': 'DecompressionError: The decompression of the file was not successful',
    'DS09': 'DecryptionError: The decryption of the file was not successful',
    'DS0A': 'DataSignRequested: Data signature is required.',
    'DS0B': 'UnknownDataSignFormat: Data signature for the format is not available or invalid.',
    'DS0C': 'SignerCertificateRevoked: The signer certificate is revoked.',
    'DS0D': 'SignerCertificateNotValid: The signer certificate is not valid (revoked or not active).',
    'DS0E': 'IncorrectSignerCertificate: The signer certificate is not present.',
    'DS0F': 'SignerCertificationAuthoritySignerNotValid: The authority of the signer certification sending the certificate is unknown.',
    'DS0G': 'NotAllowedPayment: Signer is not allowed to sign this operation type.',
    'DS0H': 'NotAllowedAccount: Signer is not allowed to sign for this account.',
    'DS0K': 'NotAllowedNumberOfTransaction: The number of transaction is over the number allowed for this signer.',
    'DS10': 'Signer1CertificateRevoked: The certificate is revoked for the first signer.',
    'DS11': 'Signer1CertificateNotValid: The certificate is not valid (revoked or not active) for the first signer.',
    'DS12': 'IncorrectSigner1Certificate: The certificate is not present for the first signer.',
    'DS13': 'SignerCertificationAuthoritySigner1NotValid: The authority of signer certification sending the certificate is unknown for the first signer.',
    'DS14': 'UserDoesNotExist: The user is unknown on the server',
    'DS15': 'IdenticalSignatureFound: The same signature has already been sent to the bank',
    'DS16': 'PublicKeyVersionIncorrect: The public key version is not correct. This code is returned when a customer sends signature files to the financial institution after conversion from an older program version (old ES format) to a new program version (new ES format) without having carried out re-initialisation with regard to a public key change.',
    'DS17': 'DifferentOrderDataInSignatures: Order data and signatures don’t match',
    'DS18': 'RepeatOrder: File cannot be tested, the complete order has to be repeated. This code is returned in the event of a malfunction during the signature check, e.g. not enough storage space.',
    'DS19': 'ElectronicSignatureRightsInsufficient: The user’s rights (concerning his signature) are insufficient to execute the order',
    'DS20': 'Signer2CertificateRevoked: The certificate is revoked for the second signer.',
    'DS21': 'Signer2CertificateNotValid: The certificate is not valid (revoked or not active) for the second signer.',
    'DS22': 'IncorrectSigner2Certificate: The certificate is not present for the second signer.',
    'DS23': 'SignerCertificationAuthoritySigner2NotValid: The authority of signer certification sending the certificate is unknown for the second signer.',
    'DS24': 'WaitingTimeExpired: Waiting time expired due to incomplete order',
    'DS25': 'OrderFileDeleted: The order file was deleted by the bank server  (for multiple reasons)',
    'DS26': 'UserSignedMultipleTimes: The same user has signed multiple times',
    'DS27': 'UserNotYetActivated: The user is not yet activated (technically)',
    'DT01': 'InvalidDate: Invalid date (eg, wrong or missing settlement date)',
    'DT02': 'InvalidCreationDate: Invalid creation date and time in Group Header (eg, historic date)',
    'DT03': 'InvalidNonProcessingDate: Invalid non bank processing date (eg, weekend or local public holiday)',
    'DT04': 'FutureDateNotSupported: Future date not supported',
    'DT05': 'InvalidCutOffDate: Associated message, payment information block or transaction was received after agreed processing cut-off date, i.e., date in the past.',
    'DT06': 'ExecutionDateChanged: Execution Date has been modified in order for transaction to be processed',
    'DU01': 'DuplicateMessageID: Message Identification is not unique.',
    'DU02': 'DuplicatePaymentInformationID: Payment Information Block is not unique.',
    'DU03': 'DuplicateTransaction: Transaction is not unique.',
    'DU04': 'DuplicateEndToEndID: End To End ID is not unique.',
    'DU05': 'DuplicateInstructionID: Instruction ID is not unique.',
    'DUPL': 'DuplicatePayment: Payment is a duplicate of another payment',
    'ED01': 'CorrespondentBankNotPossible: Correspondent bank not possible.',
    'ED03': 'BalanceInfoRequest: Balance of payments complementary info is requested',
    'ED05': 'SettlementFailed: Settlement of the transaction has failed.',
    'ED06': 'SettlementSystemNotAvailable: Interbank settlement system not available.',
    'ERIN': 'ERIOptionNotSupported: Extended Remittance Information (ERI) option is not supported.',
    'FF01': 'Invalid File Format: File Format incomplete or invalid',
    'FF02': 'SyntaxError: Syntax error reason is provided as narrative information in the additional reason information.',
    'FF03': 'InvalidPaymentTypeInformation: Payment Type Information is missing or invalid. Generic usage if cannot specify Service Level or Local Instrument code',
    'FF04': 'InvalidServiceLevelCode: Service Level code is missing or invalid',
    'FF05': 'InvalidLocalInstrumentCode: Local Instrument code is missing or invalid',
    'FF06': 'InvalidCategoryPurposeCode: Category Purpose code is missing or invalid',
    'FF07': 'InvalidPurpose: Purpose is missing or invalid',
    'FF08': 'InvalidEndToEndId: End to End Id missing or invalid',
    'FF09': 'InvalidChequeNumber: Cheque number missing or invalid',
    'FF10': 'BankSystemProcessingError: File or transaction cannot be processed due to technical issues at the bank side',
    'FF11': 'ClearingRequestAborted: Clearing request rejected due it being subject to an abort operation.',
    'G000': 'Payment transferred and not tracked: In a FIToFI Customer Credit Transfer: The Status Originator transferred the payment to the next Agent or to a Market Infrastructure. The payment transfer is not tracked. No further updates will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: The Status Originator performed the account booking and transferred the cover transaction to the next Reimbursement Agent or to a Market Infrastructure. The payment transfer is not tracked. No further updates will follow from the Status Originator.',
    'G001': 'CreditDebitNotConfirmed: In a FIToFI Customer Credit Transfer: Credit to the creditor’s account may not be confirmed same day. Update will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: Debit/credit to nostro account may not be confirmed same day or Financial Institution Credit Transfer may not be transferred same day. Update will follow from the Status Originator.',
    'G002': 'CreditDebitNotConfirmed: In a FIToFI Customer Credit Transfer: Credit to the creditor’s account may not be confirmed same day. Update will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: Debit/credit to nostro account may not be confirmed same day or Financial Institution Credit Transfer may not be transferred same day. Update will follow from the Status Originator.',
    'G003': 'CreditPendingDocuments: In a FIToFI Customer Credit Transfer: Credit to creditor’s account is pending receipt of required documents. The Status Originator has requested creditor to provide additional documentation. Update will follow from the Status Originator.  In a Financial Institution Credit Transfer with cover: Status Originator has requested a previous Agent to provide additional information/correct information. Update will follow from the Status Originator.',
    'G004': 'CreditPendingFunds: In a FIToFI Customer Credit Transfer: Credit to the creditor’s account is pending, status Originator is waiting for funds provided via a cover. Update will follow from the Status Originator.',
    'G005': 'DeliveredWithServiceLevel: Payment has been delivered to creditor agent with service level.',
    'G006': 'DeliveredWIthoutServiceLevel: Payment has been delivered to creditor agent without service level.',
    'ID01': 'CorrespondingOriginalFileStillNotSent: Signature file was sent to the bank but the corresponding original file has not been sent yet.',
    'MD01': 'NoMandate: No Mandate',
    'MD02': 'MissingMandatoryInformationIn Mandate: Mandate related information data required by the scheme is missing.',
    'MD05': 'CollectionNotDue: Creditor or creditor\'s agent should not have collected the direct debit',
    'MD06': 'RefundRequestByEndCustomer: Return of funds requested by end customer',
    'MD07': 'EndCustomerDeceased: End customer is deceased.',
    'MS02': 'NotSpecifiedReasonCustomer Generated: Reason has not been specified by end customer',
    'MS03': 'NotSpecifiedReasonAgent  Generated: Reason has not been specified by agent.',
    'NARR': 'Narrative: Reason is provided as narrative information in the additional reason information.',
    'NERI': 'NoERI: Credit transfer is tagged as an Extended Remittance Information (ERI) transaction but does not contain ERI.',
    'RC01': 'BankIdentifierIncorrect: Bank identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode).',
    'RC02': 'InvalidBankIdentifier: Bank identifier is invalid or missing. Generic usage if cannot specify between debit or credit account',
    'RC03': 'InvalidDebtorBankIdentifier: Debtor bank identifier is invalid or missing',
    'RC04': 'InvalidCreditorBankIdentifier: Creditor bank identifier is invalid or missing',
    'RC05': 'InvalidBICIdentifier: BIC identifier is invalid or missing. Generic usage if cannot specify between debit or credit account.',
    'RC06': 'InvalidDebtorBICIdentifier: Debtor BIC identifier is invalid or missing',
    'RC07': 'InvalidCreditorBICIdentifier: Creditor BIC identifier is invalid or missing',
    'RC08': 'InvalidClearingSystemMemberIdentifier: ClearingSystemMemberidentifier is invalid or missing. Generic usage if cannot specify between debit or credit account',
    'RC09': 'InvalidDebtorClearingSystemMemberIdentifier: Debtor ClearingSystemMember identifier is invalid or missing',
    'RC10': 'InvalidCreditorClearingSystemMemberIdentifier: Creditor ClearingSystemMember identifier is invalid or missing',
    'RC11': 'InvalidIntermediaryAgent: Intermediary Agent is invalid or missing',
    'RC12': 'MissingCreditorSchemeId: Creditor Scheme Id is invalid or  missing',
    'RCON': 'R-MessageConflict: Conflict with R-Message',
    'RF01': 'NotUniqueTransactionReference: Transaction reference is not unique within the message.',
    'RR01': 'Missing Debtor Account or Identification: Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Missing Debtor Name or Address: Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR03': 'Missing Creditor Name or Address: Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing.',
    'RR04': 'RegulatoryReason: Regulatory Reason',
    'RR05': 'RegulatoryInformationInvalid: Regulatory or Central Bank Reporting information missing, incomplete or invalid.',
    'RR06': 'TaxInformationInvalid: Tax information missing, incomplete or invalid.',
    'RR07': 'RemittanceInformationInvalid: Remittance information structure does not comply with rules for payment type.',
    'RR08': 'RemittanceInformationTruncated: Remittance information truncated to comply with rules for payment type.',
    'RR09': 'InvalidStructuredCreditorReference: Structured creditor reference invalid or missing.',
    'RR10': 'InvalidCharacterSet: Character set supplied not valid for the country and payment type.',
    'RR11': 'InvalidDebtorAgentServiceID: Invalid or missing identification of a bank proprietary service.',
    'RR12': 'InvalidPartyID: Invalid or missing identification required within a particular country or payment type.',
    'S000': 'ValidRequestForCancellationAcknowledged: Request for Cancellation is acknowledged following validation.',
    'S001': 'UETRFlaggedForCancellation: Unique End-to-end Transaction Reference (UETR) relating to a payment has been identified as being associated with a Request for Cancellation.',
    'S002': 'NetworkStopOfUETR: Unique End-to-end Transaction Reference (UETR) relating to a payment has been prevent from traveling across a messaging network.',
    'S003': 'RequestForCanacellationForwarded: Request for Cancellation has been forwarded to the payment processing/last payment processing agent.',
    'S004': 'RequestForCancellationDeliveryAcknowledgement: Request for Cancellation has been acknowledged as delivered to payment processing/last payment processing agent.',
    'SL01': 'Specific Service offered by Debtor Agent: Due to specific service offered by the Debtor Agent',
    'SL02': 'Specific Service offered by Creditor Agent: Due to specific service offered by the Creditor Agent',
    'SL11': 'Creditor not on Whitelist of Debtor: Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account.',
    'SL12': 'Creditor on Blacklist of Debtor: Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account.',
    'SL13': 'Maximum number of Direct Debit Transactions exceeded: Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent.',
    'SL14': 'Maximum Direct Debit Transaction Amount exceeded: Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent.',
    'TA01': 'TransmissonAborted: The transmission of the file was not successful – it had to be aborted (for technical reasons)',
    'TD01': 'NoDataAvailable: There is no data available (for download)',
    'TD02': 'FileNonReadable: The file cannot be read (e.g. unknown format)',
    'TD03': 'IncorrectFileStructure: The file format is incomplete or invalid',
    'TM01': 'InvalidCutOffTime Formerly:  CutOffTime: Associated message, payment information block, or transaction was received after agreed processing cut-off time.',
    'TS01': 'TransmissionSuccessful: The (technical) transmission of the file was successful.',
    'TS04': 'TransferToSignByHand: The order was transferred to pass by accompanying note signed by hand',
}

# ExternalTechnicalInputChannel1Code
TECHNICAL_INPUT_CHANNEL = {
    'FAXI': 'Fax: Technical Input Channel is fax or facsimile',
    'PAPR': 'Paper: Technical Input Channel is paper',
    'TAPE': 'Tape: Technical Input Channel is tape',
    'WEBI': 'Internet: Technical Input Channel is internet',
}

# ExternalVerificationReason1Code
VERIFICATION_REASON = {
}

# ExternalDocumentPurpose1Code
DOCUMENT_PURPOSE = {
    'CONF': 'Confirmed: The document represents a document that has been confirmed, for example an invoice that has been confirmed by the buyer for payment.',
    'FINV': 'Factored invoice: The document represents an invoice submitted under a factoring arrangment.',
}

# ExternalDocumentType1Code
DOCUMENT_TYPE = {
    'CINV': 'CommercialInvoice: Document is an invoice.',
    'CNFA': 'CreditNoteRelatedToFinancialAdjustment: Document is a credit note for the final amount settled for a commercial transaction.',
    'CONT': 'Contract: Document is a contract evidencing an agreement between the seller and buyer for the supply of goods and/or services.',
    'CREN': 'CreditNote: Document is a credit note.',
    'DEBN': 'DebitNote: Document is a debit note.',
    'DISP': 'DispatchAdvice: Document is an advice of despatch of the goods.',
    'DNFA': 'DebitNoteRelatedToFinancialAdjustment: Document is a debit note for the final amount settled for a commercial transaction.',
    'HIRI': 'HireInvoice: Document is an invoice for the hiring of human resources or renting goods or equipment.',
    'INVS': 'InvoiceSigned: Document is a signed invoice.',
    'MSIN': 'MeteredServiceInvoice: Document is an invoice claiming payment for the supply of metered services, eg. Gas or electricity, supplied to a fixed meter.',
    'PROF': 'ProformaInvoice: In trade transactions, a pro forma invoice is a document that states a commitment from the seller to sell goods to the buyer at specified prices and terms. It is used to declare the value of the trade. It is not a true invoice, because it is not used to record accounts receivable for the seller and accounts payable for the buyer.',
    'PUOR': 'PurchaseOrder: Document is a purchase order.',
    'QUOT': 'Quotation: Document is a quotation setting out the conditions under which the goods and/or services are offered.',
    'SBIN': 'SelfBilledInvoice: Document is a statement of the transactions posted to the debtor\'s account at the supplier.',
    'SPRR': 'SellerPresentment: Document is a document presented by the seller in support of the procurement of goods and/or services.',
    'TISH': 'TimeSheet: Document is a timesheet recording times for the provision of services and/or delivery of goods.',
    'USAR': 'UsageReport: Document is a usage report indicating the consumption pattern for designated goods and/or services.',
}

# ExternalIncoterms1Code
INCOTERMS = {
    'CFR': 'CostAndFreight: Cost and Freight (sea and inland waterway transport) - Incoterms 2010',
    'CIF': 'CostInsuranceAndFreight: Cost, Insurance and Freight (sea and inland waterway transport) - Incoterms 2010',
    'CIP': 'CarriageAndInsurancePaid: Carriage and Insurance Paid To (any mode of transport, including multimodal) - Incoterms 2010',
    'CPT': 'CarriagePaid: Carriage Paid To (any mode of transport, including multimodal) - Incoterms 2010',
    'DAP': 'DeliveredAtPlace: Delivered at Place (any mode of transport, including multimodal) - Incoterms 2010',
    'DAT': 'DeliveredAtTerminal: Delivered at Terminal (any mode of transport, including multimodal) - Incoterms 2010',
    'DDP': 'DeliveredDutyPaid: Delivered Duty Paid (any mode of transport, including multimodal) - Incoterms 2010',
    'EXW': 'ExWorks: Ex Works (any mode of transport, including multimodal) - Incoterms 2010',
    'FAS': 'FreeAlongsideShip: Free Alongside Ship (sea and inland waterway transport) - Incoterms 2010',
    'FCA': 'FreeCarrier: Free Carrier (any mode of transport, including multimodal) - Incoterms 2010',
    'FOB': 'FreeOnBoard: Free On Board (sea and inland waterway transport) - Incoterms 2010',
}

# ExternalInformationType1Code
INFORMATION_TYPE = {
    'INST': 'ProcessingInstructions: Instructions used to ease automatic request processing.',
    'OTHR': 'OtherInformation: Additional information not otherwise specified.',
    'RELY': 'RelayInstructions: Instructions used to ease automatic request relay.',
    'SHPG': 'ShippingInformation: Additional shipping information not otherwise specified.',
    'SHPM': 'ShippingMarks: Information concerning the letters, numbers or other symbols placed on the outside of cargo to facilitate identification.',
    'SLDC': 'SellerDomicileLocation: Information concerning the domicile location of the seller.',
}

# ExternalPackagingType1Code
PACKAGING_TYPE = {
    'HDPE': 'HighDensityPolyethylene: Packaging is high density polyethylene.',
    'LDPE': 'LowDensityPolyethylene: Packaging is low density polyethylene.',
    'LLDP': 'LinearLowDensityPolyethylene: Packaging is linear low density polyethylene.',
    'OTHR': 'OtherPackagingType: Other packaging type not otherwise specified.',
}

# ExternalFinancialInstrumentIdentificationType1Code
FINANCIAL_INSTRUMENT_IDENTIFICATION_TYPE = {
    'BELC': 'Code SRW (Secretariaat voor Roerende Waarden) or SVM (Secrétariat des Valeurs mobilières): National securities identification number for BE issued by the National Numbering Association SIX Telekurs Belgium.',
    'BLOM': 'Bloomberg: Ticker-like code assigned by Bloomberg to identify financial instruments.',
    'CCCD': 'Other National Securities Identification Number: National Securities Identification Number issued by the National Numbering Association for a country for which no specific financial instrument identification type code already yet. The first two letters of the code represents the country code (for example, EGDC for Egyptian NSIN). To be used only until the code is added to the ISO ExternalFinancialInstrumentIdentificationType1Code list.',
    'CMED': 'Chicago Mercantile Exchange (CME): Ticker-like code assigned by the Chicago Mercantile Exchange to identify listed-derivatives instruments.',
    'COMM': 'Common Code: National securities identification number for ICSDs issued by the National Numbering Association Clearstream and Euroclear.',
    'CTAC': 'Consolidated Tape Association (CTA): Ticker-like code assigned by the Consolidated Tape Association to identify financial instruments.',
    'CUSP': 'Committee on Uniform Security Identification Procedures (CUSIP): National securities identification number for US and CA issued by the National Numbering Association Standard & Poor´s - CUSIP Global Services.',
    'FIGC': 'Financial Instrument Global Identifier Composite: A Financial Instrument Global Identifier Composite (FIGC) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the composite level, is associated with one or more FIGI venue level ID’s and a single Share Class level ID.',
    'FIGG': 'Financial Instrument Global Identifier Share Class: A Financial Instrument Global Identifier Share Class (FIGG) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the global share class level, and is associated with one or more Composite level ID’s.',
    'FIGI': 'Financial Instrument Global Identifier: A Financial Instrument Global Identifier (FIGI) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the venue level. It is associated with one Composite ID.',
    'ISDU': 'ISDA/FpML Product URL (URL in SecurityID): URL in Description to identify OTC derivatives instruments.',
    'ISDX': 'ISDA/FpML Product Specification (XML in EncodedSecurityDesc): XML in Description to identify OTC derivatives instruments.',
    'LCHD': 'LCH-Clearnet: Ticker-like code assigned by LCH to identify listed-derivatives instruments.',
    'OCCS': 'Options Clearing Corp (OCC): Ticker-like code assigned by the Options Clearing Corporation to identify financial instruments.',
    'OPRA': 'Options Price Reporting Authority (OPRA): Ticker-like code assigned by the Options Price Reporting Authority to identify financial instruments.',
    'RCMD': 'Markit Red Code: Ticker-like code assigned by Markit to identify listed-derivatives instruments.',
    'RICC': 'Reuters Instrument Code (RIC): Ticker-like code assigned by Thomson Reuters to identify financial instruments.',
    'SEDL': 'Stock Exchange Daily Official List (SEDOL): National securities identification number for GB issued by the National Numbering Association London Stock Exchange.',
    'SICC': 'Securities Identification Code Committee: National securities identification number for JP issued by the National Numbering Association 6 Stock Exchanges and JASDEC (Securities Identification Ticker-like code Committee)',
    'TIKR': 'Ticker Symbol (TS): Ticker Code assigned by an exchange to identify financial instruments.',
    'VALO': 'VALOR: National securities identification number for CH and LI issued by the National Numbering Association SIX Telekurs Ltd.',
    'WKNR': 'Wertpapierkennummer (WKN): National securities identification number for DE issued by the National Numbering Association WM Datenservice.',
}

# ExternalTradeTransactionCondition1Code
TRADE_TRANSACTION_CONDITION = {
    'BCBL': 'BoardLot: Board lots, not set for odd lots (UK specific).',
    'BCBN': 'BadName: Bad names, not set for good names (UK specific).',
    'BCFD': 'DeliveryForm: Form of delivery, not for foreign registration when unset (UK specific).',
    'BCPD': 'DeliverCountryIncorporation: Place of delivery, in country of incorporation when unset (UK specific).',
    'BCRO': 'ResultOption: Result of option when set (UK specific).',
    'BCRP': 'ResultRepo: Result of repo when set (UK specific).',
    'BLKO': 'Block: The trade is a block trade or not, ie, whether allocation instruction will follow or not.',
    'BTEX': 'BestExecution: Trade to be executed done at best execution.',
    'BTMI': 'BoughtMinus: Bought minus indicator.',
    'CALL': 'Call: Trade to be executed following the exercise of a call option on the security.',
    'CBNS': 'CumBonus: The trade is executed cum bonus.',
    'CCPN': 'CumCoupon: The trade is executed cum coupon.',
    'CDIV': 'CumDividend: The trade is executed cum dividend.',
    'CLBR': 'ClosureBeforeRollOver: Trade to be executed for closure of a previous position before the rollover of a position (Deferred Settlement Service).',
    'CLEN': 'Clean: The trade is executed clean, ie government tax must not be paid on the accrued interest on the bond.',
    'CRST': 'CrossTrade: Cross trades are allowed whereby buy and sell orders are offset without recording the trade on the exchange',
    'CRTS': 'CumRights: The trade is executed cum rights.',
    'CWAR': 'CumWarrant: The trade is executed cum warrant.',
    'DIOR': 'DirectedOrder: A customer order where the customer gives specific instructions to the broker concerning the orders routing destination.',
    'DIRT': 'Dirty: The trade is executed dirty, ie government tax must be paid on the accrued interest on the bond.',
    'DORD': 'DirectOrder: The order is to be executed by a trading party other than the trading party to which the order is sent. In this case, the instructing party has traded with another broker which will subsequently send an advice of execution to the executing party who received the order and which is acting as clearing broker.',
    'FORW': 'ForwardPriceTrade: The order is based on a forward price.',
    'FRAC': 'Fractions: Fractional parts are allowed.',
    'GTDL': 'GuaranteedDelivery: The delivery of the financial instrument on settlement date is guaranteed.',
    'HIST': 'HistoricPriceTrade: The order is based on a historic price.',
    'MAPR': 'MarketPrice: Trade was executed at market price.',
    'MONT': 'Monthly: Trade to be executed for month-end settlement (Deferred Settlement Service).',
    'NBFR': 'NewTradeFollowingRollover: Trade to be executed for a new trade position on the next month following the roll-over of a position (Deferred Settlement Service).',
    'NCRS': 'NoCrossTrade: Cross trades, whereby buy and sell orders are offset without recording the trade on the exchange, are not allowed.',
    'NEGO': 'NegotiatedTrade: Trade for which the price is not the one quoted but an improved one, that is, the negotiated price.',
    'NMPR': 'NonMarketPrice: Trade was executed outside of normal market conditions, for example, in the case of an iceberg order.',
    'PETA': 'PreTradeAnonimity: Allows trader to explicitly request anonymity or disclosure in pre-trade market data feeds. Anonymity is relevant in markets where counterparties are regularly disclosed in order depth feeds. Disclosure is relevant when counterparties are not normally visible.',
    'PUTT': 'Putt: Trade to be executed following the exercise of a put option on the security.',
    'SETI': 'SoldExempt: Trade is exempt from short-sale rules.',
    'SPCU': 'SpecialCumDividend: The trade is executed  with a special cum dividend, ie, buying after the ex date and getting the dividend.',
    'SPEX': 'SpecialExDividend: The trade is executed  with a special ex dividend, ie, selling before the ex date without the coupon.',
    'SPSI': 'SoldPlus: Sold plus indication.',
    'SSTI': 'SoldShort: The trade is sold short. When the seller does not have the financial instrument, the delivery is effected by borrowing the financial instrument by or for the account of the seller.',
    'TEFR': 'TradeExecutedFollowingRollover: Trade executed this month following the rollover of positions.',
    'TRFR': 'TradeFollowingRollover: Trade to be executed on the next month following the roll-over of positions.',
    'WIBC': 'BeforeAuction: Transaction is before the issue date after announcement of the auction.',
    'WICD': 'AfterAuction: Transaction is after the issue date after announcement of the auction.',
    'XBNS': 'ExBonus: The trade is executed ex bonus.',
    'XCPN': 'ExCoupon: The trade is executed ex coupon.',
    'XDIV': 'ExDividend: The trade is executed ex dividend.',
    'XRTS': 'ExRights: The trade is executed ex rights.',
    'XWAR': 'ExWarrant: The trade is executed ex warrant.',
}

# ExternalChargeType1Code
CHARGE_TYPE = {
    'BRKF': 'BrokerageFee: Fee paid to a broker for services provided.',
    'BTCH': 'Batch: Fee paid for processing a batch of transactions.',
    'COMM': 'Commission: Fee paid for services provided.',
    'SUMM': 'Summation: Summation of individual fees.',
}

# ExternalCashAccountType1Code
CASH_ACCOUNT_TYPE = {
    'CACC': 'Current: Account used to post debits and credits when no specific account has been nominated.',
    'CASH': 'CashPayment: Account used for the payment of cash.',
    'CHAR': 'Charges: Account used for charges if different from the account for payment.',
    'CISH': 'CashIncome: Account used for payment of income if different from the current cash account',
    'COMM': 'Commission: Account used for commission if different from the account for payment.',
    'CPAC': 'ClearingParticipantSettlementAccount: Account used to post settlement debit and credit entries on behalf of a designated Clearing Participant.',
    'LLSV': 'LimitedLiquiditySavingsAccount: Account used for savings with special interest and withdrawal terms.',
    'LOAN': 'Loan: Account used for loans.',
    'MGLD': 'Marginal Lending: Account used for a marginal lending facility.',
    'MOMA': 'Money Market: Account used for money markets if different from the cash account.',
    'NREX': 'NonResidentExternal: Account used for non-resident external.',
    'ODFT': 'Overdraft: Account is used for overdrafts.',
    'ONDP': 'OverNightDeposit: Account used for overnight deposits.',
    'OTHR': 'OtherAccount: Account not otherwise specified.',
    'SACC': 'Settlement: Account used to post debit and credit entries, as a result of transactions cleared and settled through a specific clearing and settlement system.',
    'SLRY': 'Salary: Accounts used for salary payments.',
    'SVGS': 'Savings: Account used for savings.',
    'TAXE': 'Tax: Account used for taxes if different from the account for payment.',
    'TRAN': 'TransactingAccount: A transacting account is the most basic type of bank account that you can get. The main difference between transaction and cheque accounts is that you usually do not get a cheque book with your transacting account and neither are you offered an overdraft facility.',
    'TRAS': 'Cash Trading: Account used for trading if different from the current cash account.',
}

# ExternalDiscountAmountType1Code
DISCOUNT_AMOUNT_TYPE = {
    'APDS': 'AdditionalPromotionalDiscount: Addition discount based on third-party agreed business promotional activity, i.e., extra 10 percent discount for 15 days)',
    'STDS': 'StandingDiscount: Discount based on volume purchased.',
    'TMDS': 'TermsDiscount: Discount based on terms negotiated for payment within a specified time period, i.e., 2/10 Net 30 (2 percent discount if paid in 10 days; otherwise, net amount is due in 30 days).',
}

# ExternalTaxAmountType1Code
TAX_AMOUNT_TYPE = {
    'CITY': 'CityTax: Tax accessed by city jurisdications within a country.',
    'CNTY': 'CountyTax: Tax accessed by county jurisdications within a country.',
    'LOCL': 'LocalTax: Tax accessed by local jurisdications within a country.',
    'PROV': 'ProvinceTax: Tax accessed by province jurisdications within a country.',
    'STAT': 'StateTax: Tax accessed by state jurisdications within a country.',
}

# ExternalCardTransactionCategory1Code
CARD_TRANSACTION_CATEGORY = {
}

# ExternalBillingBalanceType1Code
BILLING_BALANCE_TYPE = {
    'ABRR': 'AdditionalBal-ReserveRequirement: The difference between the excess/(deficit) investable balance and the excess/(deficit) collected balance due to the reserve requirement. This balance is not used if the account’s Earnings Credit Rate is net of reserves. This may be used when the earnings allowance rate is not adjusted for reserves. It may be that reserves have been subtracted from the collected balance to determine the investable balance. Therefore, they must be added back to the excess/(deficit) investable balance to determine the collected balance position. The presentation of this calculation is optional. AFP code=00 04 21',
    'BEQU': 'BalEquivalent: Balance required to offset the current analysis period’s balance compensable service charges. The balance equivalent can be calculated in two different ways. The first simply multiplies the balance compensable service charge total by the multiplier.  The second calculation incorporates all of the elements of the multiplier calculation. Note that this calculation may result in a slightly different value due to the decimal precision and rounding used in the calculation: AFP code=00 04 00',
    'CBAM': 'CollectedBal-AvgNegative: The sum of only the daily ending NEGATIVE collected balances divided by the number of days in the statement period. The average negative balance, if present, is always positively signed. Balances are net of current period adjustments. Note that a NEGATIVE balance is equal to the POSITIVE balance less the NET balance. Note that a NEGATIVE Collected Balance Interest Rate can be applied to this balance to develop an OD interest charge. AFP code=00 00 13',
    'CBAN': 'CollectedBal-AvgNet: The sum of the daily ending collected balances (both positive and negative) divided by the number of days in the statement period.  A negative-signed value indicates a negative average NET balance.  If a reserve-adjusted earnings allowance/credit rate is used, this balance may be the same as the investable balance (00 00 40).  Balances are net of current period adjustments. Collected balances represent deposit money that has been collected and excludes any money in float. Note that a NET balance is equal to the POSITIVE balance less the NEGATIVE balance. Note that a NET Collected Balance OD Interest Rate (00 01 43) can be applied to this balance, if negative, to develop an OD interest charge.  AFP code=00 00 10',
    'CBAP': 'CollectedBal-AvgPositive: The sum of only the daily ending POSITIVE collected balances divided by the number of days in the statement period.  Balances are net of current period adjustments. Collected balances represent deposit money that has been collected and excludes any money in float. Note that a POSITIVE balance is equal to the NET balance plus the NEGATIVE balance. AFP code=00 00 11',
    'DABR': 'DemandDepositAccount Balance-ReserveRequirement: That portion of the demand deposit account balance that must be set aside by the bank to meet reserve requirements. AFP code=00 04 20',
    'EDCB': 'ExcessDeficitCollectedBal: Collected balance remaining after the balance required to offset the current analysis period’s balance compensable service charges has been deducted.  If negative (deficit), this represents the additional collected balance required to fully offset balance compensable service charges for the current period.  If positive (excess), this represents the collected balance surplus after offsetting balance compensable service charges for the current period. AFP code=00 04 12',
    'EDIB': 'ExcessDeficitInvestableBal: Investable balance remaining after the balance required to offset the current analysis period’s balance compensable service charges has been deducted.  If negative (deficit), this represents the additional investable balance required to fully offset balance compensable service charges for the current period.  If positive (excess), this represents the investable balance surplus after offsetting balance compensable service charges for the current period. Depending on the type of underlying account, a hard interest rate may be applied to a balance excess resulting in a hard interest credit to the underlying account. AFP code=00 04 10',
    'FDIC': 'FDICAssesmentBal: That account balance used to calculate the FDIC assessment charge. AFP code=00 00 50',
    'FLBA': 'FloatBal-Avg: The sum of the daily dollar amount of items in the process of collection divided by the number of days in the statement period.  AFP code=00 00 30',
    'FLPP': 'BalAdj-PriorPeriod-AvgFloat: Sum of the adjustments to the average float in a prior period(s).  A negative-signed value indicates a balance reduction. This balance can also be used to adjust the average collected balances since money in float has a direct effect on collected balances. AFP code=00 00 61',
    'IBAL': 'InvestableBal: Balance on which the earnings allowance/credit rate is applied.  This value can be signed either positive or negative.  A negative-signed balance indicates a shortage of investable funds.and may result in a charge. AFP code=00 00 40',
    'IBIB': 'InterestBearingInvestableBalance: The average investable balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 75',
    'IBLB': 'InterestBearingLedgerBalance: The average ledger balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 70',
    'IBNC': 'InterestBearingNetCollectedBalance: The average net collected balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 71',
    'IBNG': 'InterestBearingNegativeCollectedBalance: The average negatve collected balance that can be used to show the base balance for the calculation of a hard interest debit. This is a hard interest debit as opposed to an earnings credit debit. AFP code=00 00 73',
    'IBPC': 'InterestBearingPositiveCollectedBalance: The average positive collected balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 72',
    'IBRR': 'InterestBearingReserveRequirementBalance: The average reserve requirement balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 74',
    'LBAN': 'LedgerBal-AvgNet: The sum of the daily ending ledger balances (both positive and negative) divided by the number of days in the statement period.  A negative-signed value indicates a negative average NET balance. Balances are net of current period adjustments. The ledger balance includes any deposit money that has not been collected, ie, money in float.Note that a NET balance is equal to the POSITIVE balance less the NEGATIVE balance.Note that a NET Ledger Balance OD Interest Rate can be applied to this balance, if negative, to develop an OD interest charge.  AFP code=00 00 00',
    'LBAP': 'LedgerBal-AvgPositive: The sum of only the daily ending POSITIVE ledger balances divided by the number of days in the statement period.  Balances are net of current period adjustments. The ledger balance includes any deposit money that has not been collected, ie, money in float. Note that a POSITIVE balance is equal to the NET balance plus the NEGATIVE balance. AFP code=00 00 01',
    'LBME': 'LedgerBal-MonthEnd: Value of the book or ledger balance at the end of the calendar month. AFP code=00 00 05',
    'LBNM': 'LedgerBal-AvgNegative: The sum of only the daily ending NEGATIVE ledger balances divided by the number of days in the statement period. The average negative balance, if present, is always positively signed. Balances are net of current period adjustments. Note that a NEGATIVE balance is equal to the POSITIVE balance less the NET balance. Note that a NEGATIVE Ledger Balance Interest Rate can be applied to this balance to develop an OD interest charge. AFP code=00 00 03',
    'UCFU': 'UncollectedFundsUsed: That portion of the balance that is the difference between the average negative collected balance and the average negative ledger balance.  This is used to isolate that portion of the negative collected balance that represents the use of uncollected funds.  Balances are net of current period adjustments. Note that the Uncollected Funds Usage Rate can be applied to this balance to develop an Uncollected Funds OD interest charge.  AFP code=00 00 15',
}

# ExternalBillingCompensationType1Code
BILLING_COMPENSATION_TYPE = {
    'BACS': 'BalanceCompensableServices: Total amount of service charges that can be offset by an earnings allowance credit. Such services carry a Payment Method code of ”Balance Compensable”.  This amount is included in SettleChargeTtl-Current Period (AFP code 00 03 00). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 03 31',
    'CTND': 'ChargesAndTaxes-NetDueThisStmt: Amount due to the bank for the settlement period, after all adjustments and deductions. Includes both service and tax charges. If nothing is due this value must be sent as zero. AFP code=00 03 14',
    'DEAD': 'DeficitEarningsAllowanceDueThisStmt: Amount due to the bank for balance compensable service charges which exceed the earnings allowance for the settlement period. This amount should be equal to the absolute value of the ExcessDeficitEarningsAllowance-Adjusted (AFP code 00 02 44). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 47',
    'EALL': 'EarningsAllowance: Value of balances maintained during the statement period which can be used to offset balance compensable service charges. This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 40',
    'EANA': 'EarningsAllowance-NetAdjustment: Net value of balance and/or rate adjustments for prior periods to be applied to the current excess/(deficit) allowance. AFP code=00 02 43',
    'EDAA': 'ExcessDeficitEarningsAllowance-Adjusted: Excess/(deficit) earnings allowance for the analysis period plus or minus any net earnings allowance and/or balance compensable service charge adjustments. Note that in the absence of any EarningsAllowance-NetAdjust (AFP code 00 02 43) this balance is preferred instead of the ExcessDeficitEarningsAllowance (AFP code 00 02 41). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 44',
    'EDAL': 'ExcessDeficitEarningsAllowance: The difference between the earnings allowance and the balance compensable service charges.  Excess allowance occurs when the earnings allowance exceeds the total balance compensable service charges.  A Deficit allowance occurs when the total balance compensable service charges exceed the earnings allowance. Excess allowances may be carried forward into future statement periods at the bank’s discretion. Deficit allowances are typically reflected as charges due to the bank in the form of DeficitEarningsAllowanceDueThisStmt (AFP code 00 02 47). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 41',
    'FESS': 'FeesPaid: Charges from a prior billing period which have been paid. AFP code=00 03 22',
    'FREE': 'FreeServices: Total amount of service charges as listed in the Service Sections that are provided free of charge. Such services carry a Payment Method code of "FREE" (Free). This amount is included in SettleChargetTL-Current Period (AFP code 00 03 00). Should be sent if there are any “Free” service charges in the Service Sections. It is assumed that “waived” and “free” services are not taxed. AFP code=00 03 36',
    'NBCS': 'Non-BalCompensableServices: Total amount of service charges due as of this statement that are not eligible to be offset by an earnings allowance credit. Such services carry a Payment Method code of “FLAT" (HardCharge).  This amount is included in SettleChargeTtl-CurrentPeriod (AFP code 00 03 00 ). AFP code=00 03 00',
    'PVCS': 'PreviouslyChargedServices: Total amount of service charges as listed in the Service Sections but assessed previously and which, therefore, are not due.  Such services carry a Payment Method code of "PVCH" (PreviouslyCharged). This amount is included in SettleChargetTL-CurrentPeriod (AFP code 00 03 00). Should be sent if there are any "Previously Charged"  services in the Service Sections. AFP code=00 03 35',
    'SCAB': 'ServCharges-NetAdjust-BalCompensable: Net value of adjustments to balance compensable service charges for a prior period(s) to be applied to the current excess/(deficit) allowance. AFP cod=00 03 32',
    'SCAN': 'ServCharges-NetAdjust-Non-BalCompensable: Total of all service charge adjustments that are not eligible to be offset by an earnings allowance credit.  This can be a positive-signed or negative-signed number. AFP code=00 03 33',
    'SCBT': 'ServiceChargesDueBeforeTax: The total amount of service charges due exclusive of taxes due. AFP code=00 03 11',
    'SCCP': 'SettleChargeTtl- CurrentPeriod: Total charges before credit for services provided during the current statement period. This total is the arithmetic sum of all charges listed in the Settlement Amount element of the Service Sections in the statement regardless of the Payment Method code . It includes all Balance Compensable charges, Hard charges, Previously Charged charges, Waived charges and Free charges. It does not include any tax charges related to the services. AFP code=00 03 00',
    'SCDB': 'ServiceCharges–Debited: Amount of ChargesAndTaxes-NetDueThisStmt (AFP code 00 03 14 ) that are directly debited from the customer’s account. AFP code=00 03 50',
    'SCDI': 'ServiceCharges–Discount: The total amount of any service charge discount. AFP code=00 03 41',
    'SCIN': 'ServiceCharges–Invoiced: Amount of ChargesAndTaxes-NetDueThisStmt (AFP code 00 03 14 ) that are invoiced. AFP code=00 03 A0',
    'TICD': 'TtlInterestCredited: Total amount of hard interest credited to a designated account. The amount of hard interest credited, if any, is calculated by applying the Interest Credited rate against a negative balance as reported in the Balance Section with a Balance Identifier of  ExcessDeficitCollectedBal (AFP code 00 04 12). AFP code=00 00 76',
    'TXSC': 'TaxableServiceCharges: The total amount of service charges that were subject to taxes. AFP code=00 03 13',
    'TXTS': 'TaxTotalSum: The Sum of all the individual tax values as contained in either the individual Service Sections or Tax Sections. AFP code=00 03 60',
    'WAIV': 'WaivedServices: Amount of service charges otherwise due that are waived on this statement. Such services carry a Payment Method code of “WVED" (Waived). Note that this amount does not include line item free services (AFP code 00 03 36). This amount is included in SettleChargetTL-Current Period (AFP code 00 03 00). Any such line item waivers or free services are not brought forward into the Compensation calculations. It is assumed that “waived” and “free” services are not taxed. afp CODE=00 03 40',
}

# ExternalBillingRateIdentification1Code
BILLING_RATE_IDENTIFICATION = {
    'AEAR': 'AdjustedEarningsAllowanceRate: Per annum earnings rate, adjusted for reserves, applied to the current analysis period’s investable balance for calculation of the earnings allowance credit.  The ECR, Net of Reserves, is calculated as:    ECR, Net of Reserves  =  ECR, Not Net (00 01 22) * (1 – Reserve Rate)',
    'ANXE': 'AdjustedNextMonthEarningsRate: The anticpated earnings allowance rate, as adjusted, to be used next month in the calculation of the earnings allowance. See AEAR AdjustedEarningsAllowance Rate',
    'CDRA': 'CDRate: The current CD (Certificate of Deposit) rate as published by the bank.',
    'DINR': 'DeficiencyInterestRate: The per annum rate used to calculate the Deficiency Interest amount to be paid to the bank.',
    'DSCR': 'DeficiencySurchargeRate: The per annum rate used to calculate a surcharge based on the Deficiency Interest amount to be paid to the bank.',
    'EALR': 'EarningsAllowanceRate: Per annum earnings rate applied to the current statement period’s investable balance for calculation of the earnings allowance credit. The earnings allowance credit is used to offset the charges for balance compensable services. This rate has NOT been adjusted for reserves. The ECR, Not Net of Reserves, is calculated as:    ECR, Not Net  =  ECR, Net of Reserves (00 01 20)  /  (1 – Reserve Rate)',
    'FDIC': 'FDICRate: The current FDIC rate used in the US to calculate the Federal Deposit Insurance premium paid by the banks to the FDIC.',
    'ICDR': 'InterestCreditedRate: Per annum interest rate used to calculate the interest amount credited to a designated account. The amount of interest credited, if any, is reported in a Compensation Section with a Compensation Identifier of TtlInterestCredited',
    'MULT': 'Multiplier: The collected balance required to offset $1.00 of balance compensable service charges.  This factor can be used to calculate the balance equivalent of balance compensable service charges.  The multiplier is calculated in one of three different ways depending on whether the Earnings Allowance Rate (ECR) is adjusted for reserves or not (net of reserves or not)  and, in the case where the ECR is not adjusted for reserves, whether the multiplier is adjusted for reserves or not.',
    'NCBO': 'NetCollectedBalanceOverdraftRate: Per annum interest rate used to calculate overdraft compensation on an average net collected balance which is negative (AFP balance 00 00 10).  An average NET balance is negative when the sum of the daily ending POSITIVE and NEGATIVE balances is negative.',
    'NGCO': 'NegativeCollectedOverdraftRate: Per annum interest rate applied to NEGATIVE collected balances (AFP balance 00 00 13) for calculation of overdraft compensation.',
    'NGLO': 'NegativeLedgerOverdraftRate: Per annum interest rate applied to NEGATIVE ledger balances (AFP balance 00 00 03) for calculation of overdraft compensation.',
    'NLBO': 'NetLedgerBalanceOverdraftRate: Per annum interest rate used to calculate overdraft compensation on an average net ledger balance which is negative (AFP balance 00 00 00).  An average NET balance is negative when the sum of the daily ending POSITIVE and NEGATIVE balances is negative.',
    'NXME': 'NextMonthEarningsAllowanceRate: The anticpated earnings allowance rate to be used next month in the calculation of the earnings allowance. See EALR EarningsAllowance Rate',
    'NXMU': 'NextMonthMultiplier: The anticipated Multiplier to be used next month. See MULT Multiplier.',
    'PRIR': 'PrimeRate: The current per annum Prime rate as published by the bank.',
    'RRQR': 'ReserveRequirementRate-NonDDA: The per annum reserve rate as applied to non demand deposit accounts such as time deposit or CD accounts.',
    'RSRV': 'ReserveRequirementRate: Per annum interest rate used to calculate that portion of the CollectedBal-AvgPositive that US banks must keep on deposit at the US Federal Reserve.',
    'UFUR': 'UncollectedFundsUsageRate: Per annum interest rate assessed on that portion of the account balance which is the difference between the average negative ledger and the average negative collected balance (AFP balance 00 00 15).  This rate is used to assess compensation on the portion of the negative collected balance that represents the use of uncollected funds.',
}

# ExternalRePresentmentReason1Code
RE_PRESENTMENT_REASON = {
    'AMCR': 'Amount Corrected: Amount corrected due to proof of transaction',
    'CLSD': 'Card Authentication Liability Shift Denied: Liability Shift to acquirer due to missing card authentication method denied',
    'CRPI': 'Credit Previously Issued: Credit previously issued',
    'OTVA': 'Original Transaction Valid: Original transaction was valid',
    'VLSD': 'Verification Liability Shift Denied: Liability Shift to acquirer due to missing cardholder verification method denied',
}

# ExternalChannel1Code
CHANNEL = {
    'COUR': 'Courier: Delivery by courier.',
    'EMAL': 'Email: Transmission by e-mail.',
    'FAXI': 'Fax: Transmission by fax.',
    'MESS': 'Messenger: Delivery by messenger.',
    'POST': 'Post: Delivery by postal service.',
    'REGM': 'RegisteredMail: Delivery by registered mail services.',
    'SEMA': 'SecureEmail: Transfer via secure e-mail.',
    'SWFA': 'SWIFTNetFileAct: Transmission by SWIFTNet FileAct.',
    'SWIA': 'SWIFTNetInterAct: Transmission by SWIFTNet InterAct.',
    'SWMT': 'SWIFTMT: Transmission by SWIFT (FIN).',
    'SWMX': 'SWIFTMX: Transmission by SWIFTNet.',
    'TELE': 'Telecommunication: Transmission by telecommunications service.',
    'WEBM': 'WebUploadDownload: Available via Web upload/download',
}

# ExternalDateFrequency1Code
DATE_FREQUENCY = {
    'MNTH': 'Monthly: Frequency is monthly.',
    'QUTR': 'Quarterly: Frequency is quarterly (every three months).',
    'SEMI': 'SemiAnnual: Frequency is semi-annual (every six months).',
    'TOMN': 'TwoMonthly: Frequency is two-monthly (every two months).',
    'YEAR': 'Annual: Frequency is annual.',
}

# ExternalDocumentFormat1Code
DOCUMENT_FORMAT = {
    'DPDF': 'PDF: Document format is PDF.',
    'DXML': 'XML: Document format is XML.',
    'SDSH': 'Spreadsheet: Document format is a spreadsheet.',
    'WORD': 'Word: Document format is Word.',
    'XSLT': 'XSLT: Document format is XSLT.',
}

# ExternalModelFormIdentification1Code
MODEL_FORM_IDENTIFICATION = {
    'ISP1': 'ISP98ModelForm1: ISP98 model form for standby incorporating annexed form of payment demand with statement.',
    'ISP2': 'ISP98ModelForm2: ISP98 model form or standby providing for extension and incorporating annexed form of payment demand with alternative non-extension statement.',
    'ISP3': 'ISP98ModelForm3: ISP98 model form or standby providing for reduction and incorporating annexed form of reduction demand.',
    'ISP4': 'ISP98ModelForm4: ISP98 model form for standby providing for transfer and incorporating annexed form of transfer demand.',
    'ISP5': 'ISP98ModelForm5: ISP98 model form for simplified demand only standby.',
    'ISP6': 'ISP98ModelForm6: ISP98 model form for counter standby with annexed form of local bank undertaking.',
    'ISP7': 'ISP98ModelForm7: ISP98 model form for standby requiring confirmation.',
    'ISP8': 'ISP98ModelForm8: ISP98 model form for confirmation of standby.',
    'UDG1': 'URDGDemandGuarantee: Model form for demand guarantee defined in the latest version of the ICC Uniform Rules For Demand Guarantees (URDG).',
    'UDG2': 'URDGCounterGuarantee: Model form for counter-guarantee defined in the latest version of the ICC Uniform Rules For Demand Guarantees (URDG).',
}

# ExternalNarrativeType1Code
NARRATIVE_TYPE = {
    'ADDI': 'AdditionalTermsAndConditions: Narrative text describing the additional terms and conditions.',
    'CHAR': 'ChargeDetails: Narrative text describing the charge details.',
    'DRAW': 'DrawingDetails: Narrative text describing the drawing details.',
    'PRAS': 'ProceedsAssignable: Narrative text describing the assignment of proceeds terms and conditions.',
    'TEFF': 'TermsOfEffectiveness: Narrative text describing the terms of effectiveness.',
    'TRNF': 'Transfer: Narrative text describing the transfer terms and conditions.',
    'TVAR': 'TermsOfVariation: Narrative text describing the terms of variation.',
}

# ExternalRelativeTo1Code
RELATIVE_TO = {
    'GOOD': 'ValueOfGoods: Percentage rate expressed relative to the value of goods.',
    'PAYM': 'PaymentAmount: Percentage rate expressed relative to the payment amount.',
    'UNDG': 'UndertakingAmount: Percentage rate expressed relative to the undertaking amount.',
}

# ExternalTypeOfParty1Code
TYPE_OF_PARTY = {
    'ADVP': 'AdvisingParty: Party advising the undertaking.',
    'ANYB': 'AnyBank: Any bank.',
    'APPL': 'Applicant: Party named in the undertaking as the “applicant”.',
    'BENE': 'Beneficiary: Party in whose favour the undertaking (or counter-undertaking) is issued.',
    'CONF': 'ConfirmationParty: Party that adds its undertaking to honour the undertaking.',
    'CUB2': 'SecondCounterUndertakingBeneficiary: Beneficiary of the second counter-undertaking.',
    'CUB3': 'ThirdCounterUndertakingBeneficiary: Beneficiary of the third counter-undertaking.',
    'ISSU': 'Issuer: Party that issues the undertaking (or counter-undertaking).',
    'OBLG': 'Obligor: Party obligated to reimburse the issuer.',
    'ORDR': 'OrderingParty: Party requested to issue an undertaking on behalf of the applicant. Also known as the ordering institution or applicant\'s bank.',
    'PRES': 'PresentingParty: Party nominated to receive presentation.',
    'SADV': 'SecondAdvisingParty: Second advising party.',
    'SPEC': 'SpecifiedAddress: Party located at specified address.',
}

# ExternalUnderlyingTradeTransactionType1Code
UNDERLYING_TRADE_TRANSACTION_TYPE = {
    'CONT': 'Contract: Underlying transaction is a contract.',
    'DELV': 'DeliveryOrder: Underlying transaction is a delivery order.',
    'PROF': 'ProformaInvoice: Underlying transaction is a proforma invoice.',
    'PROJ': 'Project: Underlying transaction is a project.',
    'PUOR': 'PurchaseOrder: Underlying transaction is a purchase order.',
    'QUOT': 'Quotation: Underlying transaction is a quotation.',
    'TEND': 'Tender: Underlying transaction is a tender.',
}

# ExternalUndertakingAmountType1Code
UNDERTAKING_AMOUNT_TYPE = {
    'INCR': 'Increase: Amount is an increase.',
    'REDC': 'Reduction: Amount is a reduction.',
}

# ExternalUndertakingChargeType1Code
UNDERTAKING_CHARGE_TYPE = {
    'AMND': 'Amendment: Charge related to the issuance of an amendment.',
    'CLAM': 'Claim: Charge related to the processing of a claim.',
    'COMM': 'Commission: Commission charge.',
    'CONF': 'Confirmation: Charge for confirmation.',
    'COUR': 'Courier: Courier charge.',
    'ISSU': 'IssuanceCharge: Charge related to the issuance of an undertaking.',
    'MISC': 'Miscellaneous: Miscellaneous charge.',
    'PAYM': 'Payment: Charge related to the payment processing.',
    'POST': 'Postage: Postage charge.',
    'TELE': 'Telecommunication: Telecommunication charge.',
}

# ExternalUndertakingDocumentType1Code
UNDERTAKING_DOCUMENT_TYPE = {
    'BENS': 'BeneficiaryStatement: Document is a beneficiary statement.',
    'CINV': 'CommercialInvoice: Document is an invoice.',
    'CLAF': 'ClaimForm: Document is a claim form.',
    'DEMD': 'Demand: Document is an undertaking demand.',
    'TRAF': 'TransferForm: Document is a transfer form.',
}

# ExternalUndertakingDocumentType2Code
UNDERTAKING_DOCUMENT_TYPE2_CODE = {
    'BENS': 'BeneficiaryStatement: Document is a beneficiary statement.',
    'CINV': 'CommercialInvoice: Document is an invoice.',
    'TRAF': 'TransferForm: Document is a transfer form.',
}

# ExternalUndertakingStatusCategory1Code
UNDERTAKING_STATUS_CATEGORY = {
    'AMND': 'Amendment: Status is related to an undertaking amendment.',
    'AMTC': 'CounterUndertakingAmountStatus: Status is related to a counter-undertaking amount.',
    'AMTU': 'UndertakingAmountStatus: Status is related to an undertaking amount.',
    'APPL': 'Application: Status is related to an undertaking application.',
    'BAMD': 'BeneficiaryAmendment: Status is related to an undertaking amendment requested by the beneficiary.',
    'CONF': 'Confirmation: Status is related to an undertaking confirmation.',
    'DEMD': 'Demand: Status is related to an undertaking demand.',
    'NEXT': 'NonExtension: Status is related to an undertaking non-extension request.',
    'TERM': 'Termination: Status is related to an undertaking termination.',
}

# ExternalUndertakingType1Code
UNDERTAKING_TYPE = {
    'APAY': 'AdvancePayment: Undertaking in support of an advance payment obligation.',
    'COMM': 'Commercial: Undertaking in support of a commercial obligation.',
    'CUST': 'Customs: Undertaking in support of a customs duty obligation.',
    'DPAY': 'DirectPay: Undertaking representing the primary means of payment.',
    'FINC': 'Financial: Undertaking in support of a financial obligation.',
    'INSU': 'Insurance: Undertaking in support of a insurance obligation.',
    'IRBO': 'IndustrialRevenueBoard: Undertaking in support of an Industrial Revenue Board (IRB) obligation.',
    'MAIN': 'Maintenance: Undertaking in support of a maintenance obligation.',
    'PAYM': 'Payment: Undertaking in support of a payment obligation.',
    'PERF': 'Performance: Undertaking in support of a performance obligation.',
    'RETN': 'Retention: Undertaking in support of a monetary retention obligation.',
    'SHIP': 'Shipping: Undertaking in support of a sea transportation obligation.',
    'TEND': 'TenderOrBid: Undertaking in support of a tender or bid obligation.',
    'WARR': 'Warranty: Undertaking in support of a warranty obligation.',
}

# ExternalDocumentLineType1Code
DOCUMENT_LINE_TYPE = {
    'ADPI': 'Additional Product Identification Assigned by the Manufacturer: Line item reference is an additional product identification assigned by the manufacturer.',
    'AISB': 'Alternate ISBN: Line item reference is an alternate International Standard Book Number (ISBN).',
    'ASNB': 'Asset Number: Line item reference is an asset number.',
    'CTNB': 'Catalog Number: Line item reference is a catalog number.',
    'DBSP': 'Dun & Bradstreet Standard Product and Service Code: Line item reference is Dun & Bradstreet Standard Product and Service code.',
    'EANN': 'European Article Number (EAN) (2-5-5-1): Line item reference is an European Article Number (EAN).',
    'EINB': 'Equipment Identification Number: Line item reference is an equipment identification number.',
    'GSNB': 'General Specification Number: Line item reference is a general specification number.',
    'HIBC': 'HIBC (Health Care Industry Bar Code): Line item reference is a Health Care Industry Bar Code (HIBC)',
    'ISBN': 'International Standard Book Number (ISBN): Line item reference is an International Standard Book Number (ISBN).',
    'LTNB': 'Lot Number: Line item reference is a lot number.',
    'MDNB': 'Model Number: Line item reference is a model number',
    'PRNB': 'Part Number: Line item reference is a part reference number.',
    'PTCD': 'Product Type Code: Line item reference is a product type code.',
    'SKNB': 'Stock Number: Line item reference is a stock number.',
    'STNB': 'Style Number: Line item reference is a style number.',
    'TONB': 'Technical Order Number: Line item reference is a technical order number.',
    'UPCC': 'UPC Consumer Package Code: Line item reference is an UPC consumer package code.',
    'UPNB': 'Universal Product Number: Line item reference is an Universal Product Number.',
}

# ExternalGarnishmentType1Code
GARNISHMENT_TYPE = {
    'GNCS': 'GarnishmentForChildSupport: Garnishment from a third party payer for Child Support',
    'GNDP': 'GarnishmentForChildSupportFromDirectPayer: Garnishment from a direct payer for Child Support',
    'GTPP': 'GarnishmentToTaxingAgency: Garnishment from a third party payer to taxing agency',
}

# ExternalTradeMarket1Code
TRADE_MARKET = {
    'FDMS': 'FactoringDomestic: Factoring service provider, Factoring client and third party in the same country',
    'FEXP': 'FactoringExport: Factoring service provider, Factoring client in the same country, third party in another country',
    'FFDM': 'FactoringForeignDomestic: Factoring client and third party in the same country, Factoring service provider in another country',
    'FFDT': 'FactoringFrenchDomTom: Factoring service provider, Factoring client and third party in the same country, but factoring client has an exceptional VAT ruling, for example if it’s overseas',
    'FIMP': 'FactoringImport: Factoring service provider and third party in the same country, Factoring client in another country',
    'FREX': 'FactoringReexportedExport: Factoring service provider, Factoring client and third party in three different countries',
}

# ExternalMandateSetupReason1Code
MANDATE_SETUP_REASON = {
}

# ExternalValidationRuleIdentification1Code
VALIDATION_RULE_IDENTIFICATION = {
    'CCTR': 'Cross-border Transactions Currency Control Reporting: Identifies the validation rules related to the Russian Cross-border Transactions Currency Control Reporting',
    'ITRP': 'Invoice Tax Reporting: Identifies the validation rules related to the invoice tax reporting',
    'MMSR': 'Money Market Statistical Reporting: Identifies the validation rule scheme related to the ECB Euro Money Market Statistical Reporting',
    'SMMD': 'Sterling Money Market Daily: Identifies the validation rules related to the Bank Of England Sterling Money Market Daily Reporting',
}

# ExternalContractClosureReason1Code
CONTRACT_CLOSURE_REASON = {
    'PCED': 'Completed Contract: The parties have fulfilled all liabilities under the contract (loan agreement), including fulfillment of the liabilities by a resident third party (by another resident party).',
    'POTR': 'Other reasons that the liabilities of the contract are fufilled: If the liabilities under the contract (loan agreement) are fulfilled (stopped) on other grounds, not mentioned in the currency control regulation.',
    'PRNR': 'Contract Registration Not Required: At the termination of the grounds (under the regulation) require the registered contract to be issued, including the cases resulting from making the appropriate changes and (or) additions to the contract (loan agreement), or if the registered contract has been wrongly issued in the absence in the contract (loan agreement) of any grounds for its issuance.',
    'PSBT': 'Party cedes a claim or transfers a debt to another resident  party: The resident cedes a claim under the contract (loan agreement) to another resident  party, or transfers a debt under the contract (loan agreement) to another resident  party.',
    'PSNR': 'Party subsituted registration is not required: The resident cedes a claim under the contract (loan agreement) to a non-resident.',
    'PTAA': 'Transferred to Another Registration Agent or All Accounts closed: The registered contract has been transferred from the bank together with the transfer of the underlying contract (loan agreement) for servicing to another authorised bank (to another affiliate of this authorised bank, from the head office to an affiliate of this authorised bank, or from an affiliate to the head office of this authorised bank), as well as if the resident closes all settlement accounts in the bank of the registered contract.',
    'RACC': 'All Accounts Closed: All customer\'s accounts are closed: In the case the resident closes all settlement accounts at the bank where the contract was registered  without closing the registered contract according to the regulation, the bank  shall be entitled to independently close the registered contract after the expiration of 30 working days following the date of closing of the settlement account (last settlement account) of the resident.',
    'RCED': 'All Contract liabilities have been fulfilled by the Registration Agent: If the bank has all information available for the closing of the registered contract, and all liabilities under the contract (loan agreement) have been fulfilled (terminated), while the resident has not filled an application for closing the registered contract.',
    'REXP': 'Registration Expired: In case of failure (on the basis of the information available in the registered contracts data base at the bank) of all obligations under the contract (loan agreement), and failure to provide by a resident of the documents and information (under the regulation), based on which the registered agent conducts a statement of banking supervision, within 180 calendar days following the date specified in the specified section (for example column 6 of Section 3 for Russia) of the registered contract. In the case referred to in this paragraph, the bank informs  (at its discretion) the resident about the closure of the registered contract not later than in two working days after the date of its closure.',
}

# ExternalContractBalanceType1Code
CONTRACT_BALANCE_TYPE = {
    'EXPC': 'Current Exposure: Revolver loan current exposure (applicable on loan contracts types)',
    'EXPT': 'Total Exposure: Total loan exposure for loans with total loan limit  (applicable on loan contracts types)',
}

# ExternalShipmentCondition1Code
SHIPMENT_CONDITION = {
    'ADVN': 'Advance Payment: Goods/service delivered after payment',
    'PMNT': 'Delivery versus Payment: Goods/service delivered at the same time as payment.',
    'TRLN': 'Trade Loan: Goods/service delivered before payment',
}

# ExternalMarketArea1Code
MARKET_AREA = {
    'ANYY': 'Any: Any market area',
    'CASH': 'Cash: Bank to bank cash movements',
    'COLL': 'Collections: Collections',
    'COMM': 'Commodities: Precious metals and other commodities such as palm oil',
    'COPA': 'Commercial Payments: Payment in which one of the parties is not a financial institution',
    'DERI': 'Derivatives: Futures contracts, options, forward contracts, swaps, etc',
    'DOCC': 'Documentary Credits: Documentary credits',
    'FOEX': 'Foreign Exchange: Foreign Exchange',
    'GUAR': 'Guarantees: Guarantees',
    'LETT': 'Letters of Credit: Letters of credit',
    'LOAN': 'Loans: Loans and deposits',
    'MMKT': 'Money Markets: Loans and deposits',
    'NDLF': 'Non Deliverable Forward: FX forward trade for which only balance is settled',
    'OFFS': 'Offshore: Offshore settlement',
    'ONSH': 'Onshore: Onshore settlement',
    'OPTI': 'Options: FX Options, swap options, etc',
    'SECU': 'Securities: Bonds, equities, futures',
    'TFIN': 'Trade Finance: Documentary credits, collections, guarantees, letters of credit',
    'TREA': 'Treasury: Cash management activities',
}

# ExternalEffectiveDateParameter1Code
EFFECTIVE_DATE_PARAMETER = {
    'SETT': 'Settlement Date: Relates to the settlement date.',
    'TRAD': 'Trade Date: Relates to the trade date.',
}

# ExternalSecuritiesPurpose1Code
SECURITIES_PURPOSE = {
    'COLL': 'Collateral Management: Relates to Collateral Management',
    'SECL': 'Securities Lending: Relates to Securities Lending',
    'STMT': 'Settlements: Relates to settlements',
}

# ExternalReceivedReason1Code
RECEIVED_REASON = {
    'NSTP': 'NotStraightThroughProcessing: Instruction was not straight through processing and had to be processed manually',
}

# ExternalAcceptedReason1Code
ACCEPTED_REASON = {
    'ADEA': 'AccountServicerDeadlineMissed: Received after the servicer\'s deadline. Processed on best effort basis',
    'NSTP': 'NotStraightThroughProcessing: Instruction was not straight through processing and had to be processed manually',
    'SMPG': 'MarketPracticeRuleDiscrepency: Instruction is accepted but does not comply with the market practice rule published for the concerned market or process',
}

# ExternalPendingProcessingReason1Code
PENDING_PROCESSING_REASON = {
    'ADEA': 'ServicerDeadlineMissed: Received after the servicer\'s deadline. Processed on best effort basis',
    'DISA': 'NaturalDisaster: Exceptional closing of all financial institutions due to natural disaster, for example, earthquake',
    'ESCA': 'Escalation: Special follow-up is taking place',
    'IAAD': 'StatusReasonInvestigation: Pending reason being investigated',
    'LPRO': 'LongerProcessing: Longer processing timeframe for this type of SSI',
    'MINF': 'MissingInformation: Information, for example, currency is missing',
    'NEWI': 'NewIssues: Financial instrument is a new issue and not yet available/tradable',
    'NEXT': 'NextProcess: Next process is launched. No processing pending problems to be reported',
    'NSTP': 'NotStraightThroughProcessing: Instruction was not straight through processing and had to be processed manually',
    'PRSY': 'SystemOnHold: Transaction was put on hold/frozen by the system',
}

# ExternalRejectedReason1Code
REJECTED_REASON = {
    'ADEA': 'ServicerDeadlineMissed: Received after the servicer\'s deadline',
    'BDAY': 'NotBusinessDay: Date is not a business day',
    'CTRC': 'ClosingTransaction: Unrecognised or invalid client',
    'DPRG': 'RejectedSinceInProgress: Request has been rejected because the instruction process is in progress or has been processed',
    'INDT': 'InvalidDetails: Some message details specified in the instruction/request are inconsistent with those that expected',
    'MISM': 'InvalidRequest: The request cannot be executed. The message requested is not valid',
    'NAUT': 'NotAuthorised: Permission to be processed is not granted',
    'NINS': 'NoInstrument: Referred instrument does not exist',
    'NOAC': 'NoAccessToService: Client has no access to the service',
    'TERM': 'ClosingDateTimeRejection: Unrecognised or invalid effective date/time',
}

# ExternalPaymentTransactionStatus1Code
PAYMENT_TRANSACTION_STATUS = {
    'ACCC': 'AcceptedSettlementCompleted: Settlement on the creditor\'s account has been completed.',
    'ACCP': 'AcceptedCustomerProfile: Preceding check of technical validation was successful. Customer profile check was also successful.',
    'ACFC': 'AcceptedFundsChecked: Preceding check of technical validation and customer profile was successful and an automatic funds check was positive.',
    'ACSC': 'AcceptedSettlementCompleted: Settlement on the debtor\'s account has been completed. Usage : this can be used by the first agent to report to the debtor that the transaction has been completed.  Warning : this status is provided for transaction status reasons, not for financial information. It can only be used after bilateral agreement',
    'ACSP': 'AcceptedSettlementInProcess: All preceding checks such as technical validation and customer profile were successful and therefore the payment initiation has been accepted for execution.',
    'ACTC': 'AcceptedTechnicalValidation: Authentication and syntactical and semantical validation are successful',
    'ACWC': 'AcceptedWithChange: Instruction is accepted but a change will be made, such as date or remittance not sent.',
    'ACWP': 'AcceptedWithoutPosting: Payment instruction included in the credit transfer is accepted without being posted to the creditor customer’s account.',
    'CANC': 'Cancelled: Payment initiation has been successfully cancelled after having received a request for cancellation. Usage: code to be used in the context of APIs only.',
    'PATC': 'PartiallyAcceptedTechnicalCorrect: Payment initiation needs multiple authentications, where some but not yet all have been performed. Syntactical and semantical validations are successful.',
    'PDNG': 'Pending: Payment initiation or individual transaction included in the payment initiation is pending. Further checks and status update will be performed.',
    'RCVD': 'Received: Payment initiation has been received by the receiving agent.',
    'RJCT': 'Rejected: Payment initiation or individual transaction included in the payment initiation has been rejected.',
}

# ExternalPaymentGroupStatus1Code
PAYMENT_GROUP_STATUS = {
    'ACCP': 'AcceptedCustomerProfile: Preceding check of technical validation was successful. Customer profile check was also successful.',
    'ACCC': 'AcceptedSettlementCompleted: Settlement on the creditor\'s account has been completed.',
    'ACSC': 'AcceptedSettlementCompleted: Settlement on the debtor\'s account has been completed. Usage : this can be used by the first agent to report to the debtor that the transaction has been completed.  Warning : this status is provided for transaction status reasons, not for financial information. It can only be used after bilateral agreement',
    'ACSP': 'AcceptedSettlementInProcess: All preceding checks such as technical validation and customer profile were successful and therefore the payment initiation has been accepted for execution.',
    'ACTC': 'AcceptedTechnicalValidation: Authentication and syntactical and semantical validation are successful',
    'ACWC': 'AcceptedWithChange: Instruction is accepted but a change will be made, such as date or remittance not sent.',
    'PART': 'PartiallyAccepted: A number of transactions have been accepted, whereas another number of transactions have not yet achieved \'accepted\' status.',
    'PDNG': 'Pending: Payment initiation or individual transaction included in the payment initiation is pending. Further checks and status update will be performed.',
    'RCVD': 'Received: Payment initiation has been received by the receiving agent',
    'RJCT': 'Rejected: Payment initiation or individual transaction included in the payment initiation has been rejected.',
}

# ExternalCancellationReason1Code
CANCELLATION_REASON = {
    'AC03': 'InvalidCreditorAccountNumber: Wrong account number in Credit Transfer.',
    'AGNT': 'IncorrectAgent: Agent in the payment workflow is incorrect.',
    'AM09': 'WrongAmount: Amount is not the amount agreed or expected.',
    'COVR': 'CoverCancelledOrReturned: Cover payments has either been returned or cancelled.',
    'CURR': 'IncorrectCurrency: Currency of the payment is incorrect.',
    'CUST': 'RequestedByCustomer: Cancellation requested by the Debtor.',
    'CUTA': 'CancelUponUnableToApply: Cancellation requested because an investigation request has been received and no remediation is possible.',
    'DS24': 'TimeOut: Cancellation requested because the original payment order expired due to time-out.',
    'DUPL': 'DuplicatePayment: Payment is a duplicate of another payment.',
    'FRAD': 'FraudulentOrigin: Cancellation requested following a transaction that was originated fraudulently. The use of the FraudulentOrigin code should be governed by jurisdictions.',
    'FRNA': 'ForwardToNextAgent: To complement a rejection response, suggesting the request for cancelation should be forwarded to the next agent in the payment transaction chain.',
    'FRTR': 'FinalResponse: Direct Debit Tracking recalled as Mandate Cancelled',
    'INDM': 'IndemnityRequired: To express the wish to establish a bilateral indemnity agreement.',
    'SYAD': 'RequestToSettlementSystemAdministrator: Cancellation requested by System Member to Settlement System Administrator to indicate that the cancellation request must not be forwarded further in the chain.',
    'TECH': 'TechnicalProblem: Cancellation requested following technical problems resulting in an erroneous transaction.',
    'UPAY': 'UnduePayment: Payment is not justified.',
}

# ExternalMandateStatus1Code
MANDATE_STATUS = {
    'ACTV': 'Active: The mandate is active.',
    'CANC': 'Cancelled: The mandate is cancelled.',
    'EXPI': 'Expired: The mandate has passed the end date.',
    'SUSP': 'Suspended: The mandate is put on hold.',
}

# ExternalMandateSuspensionReason1Code
MANDATE_SUSPENSION_REASON = {
    'CTAM': 'ContractAmended: Mandate suspended due to amendment of the contract.',
    'CTCA': 'ContractCancellationInitiatedByDebtor: Mandate suspended due to cancellation of the contract, requested by the debtor.',
    'CTEX': 'ContractExpired: Mandate suspended due to the contract that expired.',
    'MCFC': 'MandateSuspendedFinalCollection: Mandate suspended as final collection took place.',
    'MCOC': 'MandateSuspendedOnceOffCollection: Mandate suspended as the once off collection took place.',
    'MSUC': 'MandateSuspended7ConsecutiveUnsuccessfulCollections: Mandate suspended after 7 consecutive unsuccessful collections.',
}

# ExternalAuthenticationChannel1Code
AUTHENTICATION_CHANNEL = {
    'ATMA': 'ATM: Authentication provided through ATM',
    'CARD': 'Card: Authentication provided through Card',
    'INBA': 'InternetBanking: Authentication provided through Internet Banking',
    'MOBI': 'Mobile: Authentication provided through Mobile',
}

# ExternalInvestigationExecutionConfirmation1Code
INVESTIGATION_EXECUTION_CONFIRMATION = {
    'ACDA': 'AcceptedDebitAuthorisation: Used when a creditor accepts the debit authorisation.',
    'ACNR': 'AcceptedClaimNonReceipt: The claim for non-receipt of a payment instruction is accepted.',
    'ACVA': 'AcceptedValueDateAdjustment: The claim for value date correction is accepted.',
    'CHRG': 'ChargesDetailsProvided: Further charges details are provided to resolve the case.',
    'CNCL': 'CancelledAsPerRequest: Used when a requested cancellation is successful.',
    'CONF': 'ConfirmationOfPayment: Used when a payment has been checked and was correctly executed without any intervention.',
    'CVAA': 'CorrectValueDateAlreadyApplied: The original value date was correct.',
    'CWFW': 'CancellationWillFollow: Used when a payment will be cancelled to solve an investigation case.',
    'ICOV': 'CoverInitiated: Used when a transfer of funds has been initiated (a cover payment) to resolve a case.',
    'IDUP': 'InstructionIsDuplicate: Used when the requested check for a possible duplicate instruction is confirmed.',
    'INFO': 'AdditionalInformationSent: Used when additional information has been sent to the beneficiary of a payment.',
    'IPAY': 'PaymentInitiated: Used when the result of an investigation is, or will be, the initiation of a payment instruction.',
    'IPYI': 'PaymentInstructionInitiated: Used when a payment instruction (eg. MT103) has been initiated to resolve a case.',
    'MCOV': 'CoverModified: Used when a transfer of funds has been modified (a cover payment) to resolve a case.',
    'MODI': 'ModifiedAsPerRequest: Used when a requested modification is successful.',
    'MWFW': 'ModificationWillFollow: Used when the payment will be modified to solve an investigation case.',
    'PDCR': 'PendingCancellationRequest: Used when a requested cancellation is pending.',
    'PECR': 'PartiallyExecutedCancellationRequest: Used when a requested cancellation has been partially executed.',
    'PURP': 'PurposeDetailsProvided: Further purpose details are provided to resolve the case.',
    'RJCR': 'RejectedCancellationRequest: Used when a requested cancellation has been rejected.',
    'RJNR': 'RejectedClaimNonReceipt: The claim for non-receipt of a payment instruction is rejected.',
    'RJVA': 'RejectedValueDateAdjustment: The claim for value date correction is rejected.',
    'SMTC': 'StatementEntryCorrect: Used when the entry in the statement is correct.',
    'SMTI': 'StatementEntryIncorrect: Used when the entry in the statement is incorrect and further information is provided with the resolution.',
    'UWFW': 'UnableToApplyWillFollow: Used when sender wants to respond to an assignment with an Unable To Apply workflow.',
}

# ExternalAgentInstruction1Code
AGENT_INSTRUCTION = {
    'CHQB': 'PayCreditorByCheque: (Ultimate) creditor must be paid by cheque.',
    'HOLD': 'HoldCashForCreditor: Amount of money must be held for the (ultimate) creditor, who will call. Pay on identification.',
    'INQR': 'InquiryReason: Additional Information to an inquiry reason must be provided.',
    'PBEN': 'PayTheBeneficiary: (Ultimate) creditor to be paid only after verification of identity.',
    'PHOA': 'PhoneNextAgent: Please advise/contact next agent by phone.',
    'PHOB': 'PhoneBeneficiary: Please advise/contact (ultimate) creditor/claimant by phone.',
    'TELA': 'TelecomNextAgent: Please advise/contact next agent by the most efficient means of telecommunication.',
    'TELB': 'Telecom: Please advise/contact (ultimate) creditor/claimant by the most efficient means of telecommunication.',
    'TFRO': 'TimeFrom: Payment instruction will be valid and eligible for execution from the date and time stipulated.',
    'TTIL': 'TimeTill: Payment instruction is valid and eligible for execution until the date and time stipulated. Otherwise, the payment instruction will be rejected.',
}

# ExternalBalanceType1Code
BALANCE_TYPE = {
    'CLAV': 'ClosingAvailable: Closing balance of amount of money that is at the disposal of the account owner on the date specified.',
    'CLBD': 'ClosingBooked: Balance of the account at the end of the pre-agreed account reporting period. It is the sum of the opening booked balance at the beginning of the period and all entries booked to the account during the pre-agreed account reporting period.',
    'FWAV': 'ForwardAvailable: Forward available balance of money that is at the disposal of the account owner on the date specified.',
    'INFO': 'Information: Balance for informational purposes.',
    'ITAV': 'InterimAvailable: Available balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified.',
    'ITBD': 'InterimBooked: Balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified.',
    'OPAV': 'OpeningAvailable: Opening balance of amount of money that is at the disposal of the account owner on the date specified.',
    'OPBD': 'OpeningBooked: Book balance of the account at the beginning of the account reporting period. It always equals the closing book balance from the previous report.',
    'PRCD': 'PreviouslyClosedBooked: Balance of the account at the previously closed account reporting period. The opening booked balance for the new period has to be equal to this balance. Usage: the previously booked closing balance should equal (inclusive date) the booked closing balance of the date it references and equal the actual booked opening balance of the current date.',
    'XPCD': 'Expected: Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day balance if everything is booked on the account and no other entry is posted.',
}

# ExternalClaimNonReceiptRejection1Code
CLAIM_NON_RECEIPT_REJECTION = {
    'NOOR': 'No Original Transaction Received: Original credit transfer never received.',
    'RNPR': 'Original Transaction Received but Not Processable: Original credit transfer was received but is not processable.',
    'ARJT': 'AlreadyRejectedTransaction: Already rejected original SCT (SEPA Credit Transfer).',
    'ARDT': 'AlreadyReturnedTransaction: Already returned original SCT (SEPA Credit Transfer).',
    'RR04': 'Regulatory reason: Regulatory reason.',
}

# ExternalCommunicationFormat1Code
COMMUNICATION_FORMAT = {
}

# ExternalCreditLineType1Code
CREDIT_LINE_TYPE = {
}

# ExternalEntryStatus1Code
ENTRY_STATUS = {
    'BOOK': 'Booked: Booked means that the transfer of money has been completed between account servicer and account owner. Usage: Status Booked does not necessarily imply finality of money as this depends on other factors such as the payment system used, the completion of the end-to-end transaction and the terms agreed between account servicer and owner. Status Booked is the only status that can be reversed.',
    'FUTR': 'Future: Entry is on the books of the account servicer and value will be applied to the account owner at a future date and time.',
    'INFO': 'Information: Entry is only provided for information, and no booking on the account owner\'s account in the account servicer\'s ledger has been performed.',
    'PDNG': 'Pending: Booking on the account owner\'s account in the account servicer\'s ledger has not been completed. Usage: this can be used for expected items, or for items for which some conditions still need to be fulfilled before they can be booked. If booking takes place, the entry will be included with status Booked in subsequent account report or statement. Status Pending cannot be reversed.',
}

# ExternalPaymentCancellationRejection1Code
PAYMENT_CANCELLATION_REJECTION = {
    'AC04': 'ClosedAccountNumber: Account number specified has been closed on the receiver’s books.',
    'ADAC': 'AwaitingDebitAuthorityFromCustomer: Reported when the cancellation request cannot be processed because customer has not yet provided the debit authority on its account.',
    'AGNT': 'AgentDecision: Reported when the cancellation cannot be accepted because of an agent refuses to cancel.',
    'AM04': 'InsufficientFunds: Amount of funds available to cover specified message amount is insufficient.',
    'ARDT': 'AlreadyReturned: Cancellation not accepted as the transaction has already been returned.',
    'ARPL': 'AwaitinReply: Reported when the cancellation request cannot be processed because no reply has been  received yet from the receiver of the request message.',
    'CUST': 'CustomerDecision: Reported when the cancellation cannot be accepted because of a customer decision (Creditor).',
    'LEGL': 'LegalDecision: Reported when the cancellation cannot be accepted because of regulatory rules.',
    'NARR': 'Narrative: Reason is provided as narrative information in the additional reason information.',
    'NOAS': 'NoAnswerFromCustomer: No response from beneficiary (to the cancellation request).',
    'NOOR': 'NoOriginalTransactionReceived: Original transaction (subject to cancellation) never received.',
    'PTNA': 'PassedToTheNextAgent: Reported when the cancellation request cannot be accepted because the payment instruction has been passed to the next agent.',
    'RQDA': 'RequestingDebitAuthority: Reported when authority is required by the Creditor to return the payment.',
    'WSEQ': 'WrongSequence: Reported when the cancellation request cannot be processed because the sequence referred to in the request is not valid.',
}

# ExternalPaymentModificationRejection1Code
PAYMENT_MODIFICATION_REJECTION = {
    'UM01': 'UnableToModifyRelatedReference: Related transaction reference cannot be modified.',
    'UM02': 'UnableToModifyPaymentServiceLevel: Service level element of payment type cannot be modified(former UnableToModifyBankOperationCode).',
    'UM03': 'UnableToModifyCategoryPurpose: Category purpose element of payment type cannot be modified (former UnableToModifyInstructionCode).',
    'UM04': 'UnableToModifyRequestedExecutionDate: RequestedExecutionDate cannot be modified.',
    'UM05': 'UnableToModifyInterbankSettlementDate: InterbankSettlementDate cannot be modified (former UnableToModifyValueDate).',
    'UM06': 'UnableToModifyInterbankSettlementAccount: SettlementAccount cannot be modified (former UnableToModifyInterbankSettlementAccount).',
    'UM07': 'UnableToModifyDebtor: Debtor cannot be modified.',
    'UM08': 'UnableToModifyDebtorAccount: DebtorAccount cannot be modified.',
    'UM09': 'UnableToModifyInstructedReimbursementAgent: InstructedReimbursementAgent cannot be modified (former UnableToModifyReceiverCorrespondent).',
    'UM10': 'UnableToModifyThirdReimbursementAgent: ThirdReimbursementAgent cannot be modified (former UnableToModifyThirdReimbursementInstitution).',
    'UM11': 'UnableToModifyPaymentClearingChannel: Clearing Channel element of payment type cannot be modified (former UnableToModifyPaymentScheme)',
    'UM12': 'UnableToModifyCreditorAgentAccount: Creditor agent account cannot be modified (former UnableToModifyAccountOfBeneficiaryInstitution)',
    'UM13': 'UnableToModifyCreditor: Creditor cannot be modified.',
    'UM14': 'UnableToModifyCreditorAccount: Creditor account cannot be modified.',
    'UM15': 'UnableToModifyRemittanceInformation: Remittance information cannot be modified.',
    'UM16': 'UnableToModifyPaymentPurpose: PaymentPurpose cannot be modified.',
    'UM17': 'UnableToModifyChargeBearer: Charge bearer cannot be modified (former UnableToModifyDetailsOfCharges).',
    'UM18': 'UnableToModifyInstructionForNextAgent: Instruction for next agent cannot be modified (former UnableToModifySenderToReceiver).',
    'UM19': 'UnableToModifyInstructionForCreditorAgent: Instruction for creditor agent cannot be modified. (former UnableToModifyInstructionForFinalAgent).',
    'UM20': 'InstructionCancelledSubmitNewInstruction: Used to inform of cancellation and request a new payment instruction. This should only be used if an agent does not want to modify a pending payment.',
    'UM21': 'UnableToModifySubmitCancellation: Modification is not possible and the cancellation is requested.',
    'UM22': 'UnableToModifyDebtorAgentAccount: Debtor agent account cannot be modified (applicable for direct debits).',
    'UM23': 'UnableToModifyInterbankSettlementAmount: Interbank settlement amount cannot be modified.',
    'UM24': 'UnableToModifyInstructionForDebtorAgent: Instruction for debtor agent cannot be modified (applicable for direct debits)',
    'UM25': 'UnableToModifyRequestedCollectionDate: Requested collection date cannot be modified (applicable for direct debits)',
    'UM26': 'UnableToModifyPaymentType: Payment type cannot be modified.',
    'UM27': 'UnableToModifyInstructedAmount: Instructed or equivalent amount cannot be modified.',
}

# ExternalPaymentCompensationReason1Code
PAYMENT_COMPENSATION_REASON = {
    'VADA': 'Value Date Adjustment: Compensation requested for value date correction.',
}

# ExternalPaymentControlRequestType1Code
PAYMENT_CONTROL_REQUEST_TYPE = {
    'RT01': 'ReleasePending: Type is a request to release the pending transactions.',
    'RT02': 'HoldNormal: Type is a request to hold normal transactions.',
    'RT03': 'Cancellation: Type is a request to cancel a transaction.',
    'RT04': 'ReSequence: Type is a request to change the sequence of the transactions.',
    'RT05': 'ReleaseSuspicious: Type is a request to release the suspicious transactions.',
}

# ExternalEnquiryRequestType1Code
ENQUIRY_REQUEST_TYPE = {
    'RT11': 'BankPositionEnquiry: Type is an enquiry on the bank\'s position.',
    'RT12': 'SpecificTransactionEnquiry: Type is an enquiry on a specific transaction.',
    'RT13': 'QueuedTransactionEnquiry: Type is an enquiry on a queued transaction.',
    'RT14': 'SuspiciousTransactionEnquiry: Type is an enquiry on a suspicious transaction.',
    'RT16': 'SytemTimeEnquiry: Type is an enquiry on the system date and/or time.',
    'RT15': 'PendingInwardCreditsEnquiry: Type is an enquiry on pending inward credits.',
}

# ExternalSystemBalanceType1Code
SYSTEM_BALANCE_TYPE = {
    'ADJT': 'Adjustment: Average balance to be held in the settlement account at the end of each day in order to fulfil the reserve due. The approximation will be always made rounding up.',
    'ADWR': 'AvailableDMVForDiscountWindowRepo: Balance represents the available discounted market value for discount window repo.',
    'AIDR': 'AvailableDMVForIntradayRepo: Balance represents the available discounted market value for intraday repo.',
    'AVLB': 'Available: Balance of money or securities that is at the disposal of the account owner on the date specified.',
    'BLCK': 'Blocked: Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, such as the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes. In some countries, a blocked balance is known as a \'reserve\' balance.',
    'BLOC': 'BlockedTrades: Balance representing the projected total of all cash legs for trades settling via a central securities depository that have been matched but blocked in order to not settle. These blocked trades are included in the calculation for settlement (for example to avoid overdrafts). Usage rule: Blocking can be done by account owner or its counterparties. Usually this is done to chain transactions or to prioritise other trades. Blocked trades have an indicator that prevents the transactions from settling. Once matched, they can settle whenever the freeze is lifted. In this case they will move to FSET. Lifting the freeze can happen anytime during the day and the transaction will be settling in the next settlement cycle which can be the same day if the (international) central securities depository\'s operates several settlements cycles per day.',
    'BOOK': 'Book: Balance that is registered in the books of the account servicer.',
    'BSCC': 'BulkSettlementCMUPCredit: Balance represents the total of the bulk settlement and central moneymarkets unit processor credit.',
    'BSCD': 'BulkSettlementCMUPDebit: Balance represents the total of the bulk settlement and central moneymarkets unit processor debit.',
    'CCPS': 'CentralCounterparty: Balance representing the forecast of the total of all cash legs of transactions traded in exchanges that operate a central counterparty functionality.',
    'CLSG': 'Closing: Balance of the account at the end of the account servicer\'s business day. It is the sum of the opening balance at the beginning of the day and all entries booked to the account during the account servicer\'s business day.',
    'COHB': 'CreditOnHold: Balance representing the total incoming payments that were put on hold because the credit limit has been exceeded.',
    'COLC': 'DividendsCollection: Balance representing the projected total amount of all payment obligations to the participant (bank), based on their role as main paying agent.',
    'CPBL': 'CreditProcessed: Balance representing the total incoming payments that have been processed and are waiting for settlement.',
    'CRDT': 'Credit: Balance representing the sum of all credit entries booked to an account.',
    'CRRT': 'Current: Balance of the account at a precise moment in time.',
    'CUSA': 'CustodyActual: Balance representing the actual total of all asset servicing transactions such as dividends, income corporate actions equivalents, tax returns, redemptions, etc.',
    'CUST': 'Custody: Balance representing the projected total of all asset servicing transactions such as dividends, income corporate actions equivalents, tax returns, etc.',
    'DBIT': 'Debit: Balance representing the sum of all debit entries booked to an account.',
    'DLOD': 'DaylightOverdraft: Balance representing the intra day overdraft granted by the central bank to financial institutions participating in a RTGS system. This balance may vary over time and shall be offset at the end of the day.',
    'DOHB': 'DebitOnHold: Balance representing the total outgoing payments that were put on hold because the debit limit has been exceeded.',
    'DPBL': 'DebitProcessed: Balance representing the total outgoing payments that have been processed and are waiting for settlement.',
    'DSET': 'DefinitiveSettledSecurities: Balance representing the cash equivalent of all settled securities transactions.',
    'DWRD': 'DiscountWindowRepoDrawings: Balance represents the discount window repo drawings.',
    'EAST': 'EligibleAssets: Balance representing the potential loan a Central Bank would make in cash if the collateral is pledged, such as securities available and eligible as collateral with the central bank.',
    'FCOL': 'FirmCollateralisation: Balance representing the forecast of the cash-equivalent resulting from evaluation of existing holdings at central securities depositary that are qualified to serve as collateral.',
    'FCOU': 'UsedAmountsFirmCollateralisation: Balance representing the cash equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral and have been used as collateral.',
    'FORC': 'CashForecast: Balance representing the total of all balance types representing transactions to settle, blocked items and custody transactions.',
    'FSET': 'ForecastSettlement: Balance representing the forecast of total of all cash legs for trades that are ready to settle via a central securities depository. Amounts shown are still subject to processing of the securities settlement.',
    'FUND': 'NetFunding: Balance representing the net amount to be funded resulting from all transactions which have an impact on the funding requirement.',
    'FUTB': 'TotalFuture: Balance representing the total of the payments with a processing date in the future.',
    'INTM': 'Interim: Balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified.',
    'IRDR': 'IntradayRepoDrawings: Balance represents the intraday repo drawings.',
    'IRLT': 'IntradayRepoLimit: Balance represents the intraday repo limit.',
    'LACK': 'LackOfHoldingsTransactions: Balance representing the cash equivalent of transactions with a lack of holdings.',
    'LRLD': 'LimitRelated: Balance of a specific limit value, such as a bilateral balance is calculated in relation to a given bilateral limit.',
    'LTSF': 'LiquidityTransfer: Balance composed of the sum of all liquidity transfers made to or from an account.',
    'MSTR': 'Master: Balance of the identified account plus the balance of all of its subaccounts.',
    'NOTE': 'Noted: Balance representing the amount that a financial institution has set aside for a specific reason and which is therefore not available.',
    'NSET': 'NonSettledSecurities: Balance representing the cash equivalent of all non-settled securities transactions.',
    'OPNG': 'Opening: Book balance of the account at the beginning of the account servicer\'s business day. It always equals the closing book balance from the previous business day.  Note: the available balance at the beginning of the account servicer\'s business day may be different from the closing book balance from the previous business day.',
    'OTCC': 'CCPGuaranteedOTCTransactions: Balance representing the Forecast of the total of all cash-legs of transactions \'over the counter\' (OTC), going through central counter party (CCP) functions.',
    'OTCG': 'ForecastOTCTransactions: Balance representing the forecast of the total of all cash legs of transactions traded \'over the counter\' (OTC).',
    'OTCN': 'NonCCPGuaranteedOTCTransactions: Balance representing the forecast of the total of all cash legs of transactions traded \'over the counter\' (OTC) not going through central counter party (CCP) functions.',
    'OTHB': 'OtherBlockedTrades: Balance representing the projected total of all cash legs for trades settling via a central securities depository that have been matched but blocked in order to not settle. These blocked transactions are not included in the calculation for settlement.',
    'PDNG': 'Pending: Balance of securities pending delivery, such as the orders to sell securities have been executed but settlement of the open transactions has not been confirmed.',
    'PIPO': 'PayInPayOut: Balance representing the fictive forecast of automated direct debits or payment based on standing arrangements between a central securities depository and the user.    Usage: Pay-Ins and Pay-Outs can be different based on individual payment instructions or available funds.',
    'PRAV': 'ProgressiveAverage: Average of the daily balances on the account used to fulfil the reserve requirements calculated from the beginning of the maintenance period.',
    'PYMT': 'Payment: Balance representing the sum of entries as a result of payments processing. Entries relating to fees, interest, or other movements not a result of payments sent or received by the account owner are not included.',
    'REJB': 'TotalRejected: Balance representing the total of the payments that have been rejected.',
    'REPC': 'CMUPRepoCredit: Balance represents the total of the central moneymarkets unit processor repo credits.',
    'REPD': 'CMUPRepoDebit: Balance represents the total of the central moneymarkets unit processor repo debits.',
    'REST': 'Restricted: Balance of cash that may only be used under certain conditions.  Balance type is used to block securities/cash in the client account for example, when related to specific corporate actions, the holding is under the direct control of the system paying agent, who is the only one who can transfer securities out of this balance type. Also known as the "escrow balance" or "sequestered balance".',
    'SAPC': 'SAPDirectCreditAmount: Balance represents the settlement account processor direct credit amount.',
    'SAPD': 'SAPDirectDebitAmount: Balance represents the settlement account processor direct debit amount.',
    'SAPP': 'SAPQueueAmount: Balance represents the settlement account processor queue amount.',
    'SCOL': 'SelfCollateralisation: Balance representing the forecast of the cash-equivalent resulting from evaluation of the net incoming balance of securities qualified to serve as collateral for which settlement instructions are held at.',
    'SCOU': 'UsedAmountsSelfCollateralisation: Balance representing the cash-equivalent resulting from evaluation of incoming securities, qualified to serve as collateral and actually used as collateral, which have been settled during the settlement process.',
    'SELF': 'Self: Balance of the account identified (as opposed to Master Balance).',
    'THRE': 'Threshold: Balance representing the amount that will be destined for investment. Difference between available balance and threshold for investment limit.',
    'TOHB': 'TotalOnHold: Balance representing the total of the payments that were put on hold because the limits have been exceeded.',
    'TPBL': 'TotalProcessed: Balance representing the total of the payments that have been processed and are waiting for settlement during the day.',
    'XCHC': 'CCPGuaranteedForecasting: Balance representing the forecast of the total of all cash legs of transactions in exchanges, going through CCP functions.',
    'XCHG': 'ExchangeForecast: Balance representing the forecast of the total of all cash legs of transactions traded in exchanges.',
    'XCHN': 'NonCCPGuaranteedForecasting: Balance representing the forecast of the total of all cash legs of transactions traded in exchanges not going through central counter party (CCP) functions.',
    'XCRD': 'ExpectedCredit: Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day credit balance if everything books to the account and no other credit entry is posted.',
    'XDBT': 'ExpectedDebit: Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day debit balance if everything books to the account and no other debit entry is posted.',
    'XPCD': 'Expected: Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day balance if everything is booked on the account and no other entry is posted.',
}

# ExternalSystemBalanceType1Code
SYSTEM_BALANCE_TYPE = {
    'X020': 'DataNotYetAvailable: Specifies the error code when the data requested are not yet available.',
    'X030': 'MessageSizeLimitExceeded: Specifies the error code when the data requested generates a message size that exceed the processing capacity.',
    'X050': 'DataNotAvailable: Specifies the error code when the data requested have not been found.',
}

# ExternalSystemEvent1Code
SYSTEM_EVENT = {
    'CRCO': 'CashReservationCutOff: Event is the cutoff for the cash reservation window.',
    'CUSC': 'CustomerCutOff: Event is the cutoff for customer payments.',
    'ESTF': 'EndOfStandingFacilities: Event is the cut off for the standing facilities.',
    'EUCO': 'Euro1CutOff: Event is the cutoff time for the Euro1 system, that is, the deadline for processing Euro1 transactions.',
    'EUSU': 'Euro1StartUp: Event is the opening of the Euro 1 system operation.',
    'FIRE': 'FinalReporting: Event is the report after all operations have ceased in the system.',
    'IBKC': 'InterbankCutOff: Event is the cutoff for interbank payments.',
    'LTDC': 'LTDCutOff: Event is the cutoff for the settlement of the cash multilateral balances resulting from the daylight cycle of the securities settlement system.',
    'LTGC': 'LTGCutOff: Event is the cutoff for the daytime cycle of the securities settlement system.',
    'LTNC': 'LTNCutOff: Event is the cutoff for the settlement of the cash multilateral balances resulting from the overnight cycle of the securities settlement system.',
    'LVCC': 'LVPCancellationCutOff: Event is the cutoff time after which low value payments can no longer be cancelled.',
    'LVCO': 'LVPCutOff: Event is the cutoff time for low value payments processed by the system.',
    'LVRT': 'LVPCutOffReportTime: Event is the time at which the members will be provided with the report corresponding to the processing of low value payments.',
    'LWSU': 'LimitWarningStartUp: Event is the start of the limit warning period.',
    'NPCT': 'NewPaymentCutOffTime: Event is the cutoff time for the receipt of new commercial payments.',
    'PCOT': 'ProcessingCutOffTime: Event is the cutoff time for the processing of payments.',
    'RECC': 'RecCutOff: Event is the cutoff for the settlement of the multilateral balances stemming from the retail clearing system.',
    'REOP': 'ResumeOperation: Event is the expected resume time for a TARGET component.',
    'SSSC': 'NetSSSReservationCutOff: Event is the cutoff for the securities settlement system cash reservation window.',
    'STDY': 'StartOfDay: Event is the start of the operating day.',
    'STSU': 'Step1StartUp: Event is the start of the Step 1 system operation.',
    'SYSC': 'SystemCutOff: Event is the cutoff for the system.',
}

# ExternalSystemMemberType1Code
SYSTEM_MEMBER_TYPE = {
    'DRCT': 'Direct: Member has full rights in the system. In principle, this membership status entails financial responsibility for its own operations and sponsored members\' operations submitted to the system.',
    'IDRT': 'Indirect: Member has limited rights in the system specifications. In principle, this membership status entails no financial responsibility for its operations submitted to the system.',
    'RMTE': 'Remote: Member has access to the system from a remote location or through remote technical means.',
    'EURO': 'EURO1: Member is entitled to access the Euro1 system of the Euro Banking Association (EBA).',
    'STEP': 'STEP1: Member is entitled to access the Step1 system of the Euro Banking Association (EBA).',
}

# ExternalMarketInfrastructure1Code
MARKET_INFRASTRUCTURE = {
    'ABE': 'EBAEuro1Step1: EBA Euro1/Step1.',
    'ACH': 'ACH: Automated Clearing House. Payment system that clears cash transfers and settles the proceeds in a lump sum, usually on a multilateral netting basis.',
    'ACS': 'Canada: Canadian Dollar (CAD)  - Automated Clearing Settlement System (ACSS)',
    'AIP': 'Albania: AL (Albania) -  Albania Interbank Payment System.',
    'ART': 'Austrian: AT (Austria) - Austrian RTGS (ARTIS).',
    'AVP': 'NewZealand: NZ (New Zealand) - New Zealand Assured Value Payments.',
    'AZM': 'Azerbaijan: AZ (Azerbaijan) - Azerbaijan Interbank Payment System (AZIPS).',
    'BAP': 'BosniaHerzegovina: BA (Bosnia and Herzegovina).',
    'BCC': 'SwedenBGC: SE (Sweden) - Sweden BGC Clearing CUG.',
    'BCE': 'Ecuador: EC (Ecuador) - Ecuadorian Central Payment System (Sistema Central de Pagos Ecuatoriano)',
    'BDS': 'Barbados: BB (Barbados) - Barbados RTGS (CBRTGS).',
    'BEL': 'Belgium: BE (Belgium) - Belgium RTGS (ELLIPS).',
    'BGN': 'Bulgaria: BG (Bulgaria) - Bulgaria RTGS.',
    'BHS': 'Bahamas: BS (Bahamas) - Bahamas RTGS.',
    'BIS': 'Botswana: BW (Botswana) - Botswana Interbank Settlement System.',
    'BOF': 'Finland: FI (Finland) - RTGS (BOF).',
    'BOJ': 'BankOfJapanNet: the Bank of Japan clearing system.',
    'BRL': 'Italy: IT (Italy) - Italy RTGS (BIREL).',
    'BSP': 'Philippines: PH (Philippines) - Philippines Payment System.',
    'CAD': 'Canada: CA (Canada) - Canadian Large Value Transfer System (LVTS)',
    'CAM': 'SpainCAM: ES (Spain).',
    'CBA': 'Central Bank of Aruba CSM: AW (Aruba) - Central Bank of Aruba CSM',
    'CBJ': 'Ireland: IE (Ireland) - Irish RTGS (IRIS).',
    'CHI': 'USTCHChips: US - The Clearing House CHIPS',
    'CHP': 'UnitedKingdom: GB (UK) - British Euro RTGS (CHAPS).',
    'CIS': 'Central Interoperability Service: Central Interoperability Service of the EACHA Clearing Cooperative, for exchanging SEPA payments between Automated Clearing Houses in the EEA.',
    'COE': 'Columbia: CO (Columbia) - Colombian Electronic Cheque System named CEDEC (Compensación Electrónica De Cheques).',
    'COI': 'Columbia: CO (Columbia) - Colombian Central Bank´s ACH named CENIT (Compensación Electrónica Nacional Interbancaria).',
    'COU': 'Columbia: CO (Columbia) - Colombian RTGS System named CUD (Cuentas de Depósito).',
    'DDK': 'DenmarkDDK: DK (Denmark) - Danish Krone RTGS (KRONOS)',
    'DKC': 'Denmark: DK (Denmark) - Danish Euro RTGS (KRONOS)',
    'EBA': 'EBAEuro1: EBA Euro1.',
    'ELS': 'GermanyELS: DE (Germany).',
    'EMZ': 'Germany: Elektronischer Massenzahlungsverkehr (EMZ)',
    'EPM': 'ECB: ECB (European Central Bank) - ECB Payment Mechanism.',
    'EPN': 'USTCHEPN: US - The Clearing House EPN',
    'ERP': 'EBAStep1: EBA step 1 (members).',
    'FDA': 'USFedACH: US (United States) - FED-ACH',
    'FDN': 'FedNet: FedNet is a link to a Federal Bank account via the internet.  FedNet enables checking of account balance, transactions, take print outs of account statement, transfer funds to third party accounts, E-shopping, BSNL Payments, Deposit opening, Deposit Renewal, Request for Demand Draft, Cheque Book etc.',
    'FDW': 'USFedwire: US (United States) – FEDWIRE',
    'FEY': 'ForeignExchangeYenClearing: JP (Japan) the Foreign Exchange Yen Clearing system (FEYCS). It is the Japanese electronic interbank system for sending guaranteed and unconditional yen payments of FX deals for same day settlement from one settlement bank, on behalf of itself or its customers, to another settlement bank.',
    'GIS': 'Ghana: GH (Ghana) - Ghana Interbank Settlement System (GISS).',
    'HRK': 'Croatia: HR (Croatia) - HSVP.',
    'HRM': 'Greece: GR (Greece) - Greek RTGS (HERMES).',
    'HUF': 'Hungary: HU (Hungary) - VIBER.',
    'INC': 'DEandNLEquens: DE and NL - Equens',
    'JOD': 'Jordan: JO (Jordan) - Jordan RTGS.',
    'KPS': 'Kenya: KE (Kenya) - Kenyan Electronic Payment Settlement System.',
    'LGS': 'Luxemburg: LU (Luxemburg) - Luxembourg RTGS (LIPS).',
    'LKB': 'SriLanka: LK (Sri Lanka) - Sri Lanka (Lankasettle).',
    'LVL': 'Latvia: LV (Latvia).',
    'LVT': 'Canada: CA (Canada) - Large Value Transfer System (LVTS).  Replaces CAD.',
    'MEP': 'Singapore: SG (Singapore) - Singapore RTGS (MEPS+).',
    'MOS': 'SouthAfrica: ZA (South Africa) - South-African Multiple Option Settlement.',
    'MRS': 'Malta: MT (Malta) - Malta Realtime Interbank Settlement System.',
    'MUP': 'Mauritius: MU (Mauritius).',
    'NAM': 'Namibia: NA (Namibian) - Namibian Interbank Settlement System.',
    'NOC': 'Norway: NO (Norway).',
    'NPP': 'Australia: AU (Australia) - New Payments Platform (NPP)',
    'PCH': 'Switzerland: CH (Switzerland).',
    'PDS': 'Australia: AU (Australia).',
    'PEG': 'Egypt: EG (Egypt).',
    'PNS': 'FrancePNS: FR (France).',
    'PTR': 'Angola: AO (Angola) - Angola RTGS.',
    'PVE': 'Venezuela: Ve (Venezuela).',
    'ROL': 'RomaniaEPO: RO (Romania) - Romanian Electronic Payment Operations RT.',
    'ROS': 'RomaniaGSRS: RO (Romania) - Romanian GSRS.',
    'RTG': 'RTGS: Real Time Gross Settlement System. Payment system that simultaneously clears individual transfers and settles them in central bank money.',
    'RTP': 'GermanyRTGSPlus: DE (Germany).',
    'SCL': 'RPS SEPA-Clearer: DE – SEPA-Clearer of the Retail Payment System operated by Deutsche Bundesbank',
    'SCP': 'Chili: CL (Chile) - Chilean Interbank Payment System.',
    'SEC': 'SwedenSEC: SE (Sweden) - Swedish Euro RTGS (SEC).',
    'SIT': 'Slovania: SI (Slovenia).',
    'SLB': 'SpainES: ES (Spain) - Spanish RTGS (SLBE).',
    'SPG': 'Portugal: PT (Portugal) - Portuguese RTGS (SPGT).',
    'SSK': 'SwedenSSK: SE (Sweden) - SEK RTGS (RIX).',
    'ST2': 'EBAStep2: EBA Clearing STEP 2',
    'STG': 'UnitedKingdomGBP: UK (United Kingdom) - CHAPS Sterling RTGS.',
    'T2S': 'T2S: T2S.',
    'TBF': 'FranceFR: FR (France) - French RTGS (TBF).',
    'TCH': 'USTCHRealTime: US - The Clearing House Real-TimePayment System',
    'TGT': 'Target: Target.',
    'THB': 'Thailand: TH (Thailand) - Thailand Payment System (BAHTNET).',
    'THN': 'Thailand-NITMX: TH (Thailand) - National ITMX Payment System',
    'TIS': 'Tanzania: TZ (Tanzania) - Tanzania Interbank Settlement System (TISS).',
    'TOP': 'Netherlands: NL (Netherlands) - Dutch RTGS (TOP)',
    'TTD': 'TrinidadAndTobago: TT (Trinidad and Tobago ) - Trinidad and Tobago SAFE-TT.',
    'UBE': 'Canada: United States Dollar  (USD) – US Bulk Exchange Clearing System (USBE)',
    'UIS': 'Uganda: UG (Uganda) - Uganda National Interbank Settlement System.',
    'VCS': 'VocaLink: VocaLink Clearing System',
    'XCT': 'EBAStep2: EBA step 2.',
    'ZEN': 'Zengin: JP (Japan) the Zengin system. The electronic payment system for domestic third party transfers managed by the Tokyo Bankers Association.',
    'ZET': 'Zimbabwe: ZW (Zimbabwe) - Zimbabwe Electronic Transfer & Settlement System.',
    'ZIS': 'Zambia: ZM (Zambia) - Zambian Interbank Payment &Settlement System.',
}

# ExternalPaymentRole1Code
PAYMENT_ROLE = {
    'BKMG': 'BackupManager: Party responsible for managing the recovery functions related to a system.',
    'LMMG': 'LimitManager: Party in a financial institution responsible for the management of the limits. This party is responsible for fixing, modifying, or suspending limits as relevant for the management of counterpart risk or systemic risk containment.',
    'LQMG': 'LiquidityManager: Party in a financial institution responsible for the management of liquidity for the financial institution. This party has access to some functions available on the system, such as the liquidity transfers or management of standing instructions for liquidity control.',
    'PYMG': 'PaymentManager: Party in a financial institution responsible for the management of payment processing for the financial institution. This includes authorising, recycling, and modification of payment transactions.',
    'REDR': 'Reader: Party in a financial institution entitled to obtain information from the system, but not act upon/alter this information.',
    'STMG': 'SettlementManager: Party in a financial institution responsible for the management of settlement processing.',
}

# ExternalProxyAccountType1Code
PROXY_ACCOUNT_TYPE = {
    'TELE': 'TelephoneNumber: A telephone number in the format specified by the \'The international public telecommunication numbering plan ITU-T E.164.',
    'EMAL': 'EmailAddress: Internationalised address of an electronic mail box for internet messages.',
    'DNAM': 'Domain Name: Internationalised internet domain name.',
}

# ExternalAuthorityIdentification1Code
AUTHORITY_IDENTIFICATION = {
    'AUAS': 'Australian Securities and Investments Commission (ASIC)',
    'ATFM': 'Austrian Financial Market Authority (FMA)',
    'BEFS': 'Financial Services and Markets Authority (FSMA)',
    'BENB': 'National Bank of Belgium',
    'BGFS': 'Financial Supervision Commission (FSC)',
    'CACS': 'Canadian Securities Transition Office (CSTO)',
    'CYAS': 'Authority for the Supervision and Development of Cooperative Societies',
    'CYCB': 'Central Bank of Cyprus (CBC)',
    'CYCY': 'Cyprus Securities and Exchange Commission (CySEC)',
    'CZCN': 'Czech National Bank (CNB)',
    'DEBA': 'Federal Financial Supervisory Authority (BaFin)',
    'DKFI': 'Finanstilsynet',
    'EEEF': 'Estonian Financial Supervision Authority (EFSA)',
    'EUES': 'European Securities and Markets Authority (ESMA)',
    'ESBD': 'Bank of Spain (BDE)',
    'ESCN': 'Comisión Nacional del Mercado de Valores (CNMV)',
    'FIFS': 'Finanssivalvonta (FSA)',
    'FRAC': 'Autorité de Contrôle Prudentiel et de Résolution (ACPR)',
    'FRAM': 'Autorité des Marchés Financiers (AMF)',
    'GBFS': 'Financial Services Authority (FSA)',
    'GBFC': 'Financial Conduct Authority (FCA)',
    'GBPR': 'Prudential Regulation Authority (PRA)',
    'GIFS': 'Gibraltar FSC (FSC)',
    'USCF': 'US Commodity Futures Trading Commission (CFTC)',
    'GRBO': 'Bank of Greece (BOG)',
    'GRHC': 'Hellenic Capital Market Commission (HCMC)',
    'HRHA': 'Croatian Financial Services Supervisory Agency (HANFA)',
    'HUPS': 'Hungarian Financial Supervisory Authority (PSZAF)',
    'IECB': 'Central Bank of Ireland (CBI)',
    'ISFM': 'Iceland Financial Supervisory Authority (FME)',
    'ITBD': 'BANCA D\'ITALIA (BDI)',
    'ITCO': 'Commissione Nazionale per le Societa e la Borsa (CONSOB)',
    'LIFM': 'Financial Market Authority (FMA)',
    'LTLS': 'Bank of Lithuania (LSC)',
    'LUCS': 'Commission de Surveillance du Secteur Financier (CSSF)',
    'LVFK': 'Financial & Capital Market Commission (FKTK)',
    'MTMF': 'Malta Financial Services Authority (MFSA)',
    'NLAF': 'Netherlands Authority for the Financial Markets (AFM)',
    'NLDN': 'Nederlandse Bank (DNB)',
    'NOFI': 'Norwegian Financial Supervisory Authority (Finanstilsynet)',
    'PLKN': 'Polish Financial Supervisory Commission (KNF)',
    'PTBP': 'Banco de Portugal (BP)',
    'PTCM': 'Comissão do Mercado de Valores Mobiliários (CMVM)',
    'ROAS': 'Romanian Financial Supervisory Authority (ASF)',
    'SEFI': 'Finansinspektionen (FI)',
    'SIAT': 'Securities Market Agency (ATVP)',
    'SKNB': 'National Bank of Slovakia (NBS)',
}
